#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name


list_of_questions = [
    '"It\'s not what you know, it\'s who you know." Is that true?',
    'What was the last thing that blew your mind?',
    'If given the opportunity, would you have a psychic reading?',
    'Your colleagues have just given you a round of applause. What have you done?',
    "What's the last thing you Googled?",
    "Other than when you're sick, have you ever spent an entire day in your "
    'pajamas? When was the last time?',
    'If you were a gemstone, which one would you be, and why?',
    "What's your favorite heroic animal story?",
    'Justin Hayward sang "Forever Autumn” in 1976. What season would you like it '
    'to be forever?',
    'What happened on your most manic Monday?',
    'Would you keep a secret for one friend if it meant another could get into '
    'serious trouble?',
    'If a burglar broke into your house and stole just one thing, which one thing '
    'would cause the biggest inconvenience?',
    'What have you been putting off doing that you should be doing now?',
    'Have you ever played a prank on someone that backfired spectacularly?',
    'If you could outsource one daily task or chore forever, what would it be?',
    "What's your favorite golden oldie song from any decade before you were born?",
    'Do you avoid stepping on cracks in the sidewalk? Why?',
    'What three "fortunes" would you like to create and place in fortune cookies?',
    'If you could switch the lead actors in two movies, what switch would make '
    'both movies totally weird?',
    'What have you been complimented on most in your life so far?',
    'Should a life sentence actually be for life?',
    'Which character from a TV show you watched as a kid brings back the happiest '
    'memories, and why?',
    'In 1919, the Great Molasses Flood killed twenty-one people in Boston. What '
    'amazing, interesting, or obscure historical facts do you know?',
    'What have you done today that makes you feel proud?',
    "Where would you like your memorial bench to be situated once you're gone?",
    'If your favorite username was the name of a cologne or perfume, how would it '
    'smell?',
    "Helen of Troy's face launched a thousand ships. What would you like your "
    'face to be able to do?',
    'Which actor was (or is) the best James Bond?',
    "What have you done that others said you couldn't do?",
    "If a drinking glass wasn't called a glass, what name should it be given?",
    'Knowing what you know now, if you had to start high school again, what would '
    'you do differently?',
    'What have you done recently that you should have done a long time ago?',
    'Who would you like to sing a duet with? What would you sing?',
    'Have you lost contact with someone you wish you could reconnect with? Who is '
    'it?',
    'What top three hair or beauty essentials could you not live without?',
    'Which three colors best describe your personality?',
    'If animals could talk, which ones would do the most complaining?',
    "What's your favorite Halloween candy?",
    'We all know "dad jokes," but what would be a "mom joke"?',
    'How many scout knots can you tie?',
    'Which tailless animal would be most awesome with a tail?',
    'What has been your most embarrassing moment?',
    'When you receive a call from a telemarketer, what do you do?',
    'If you could change your first name, what name would you choose?',
    'When was the last time you swam in the sea?',
    'What job has the coolest uniform?',
    'Has a chance encounter ever changed the course of your life? What was it?',
    "What's the worst thing you've had stuck in your teeth?",
    'A box of puppies has been abandoned on your doorstep. What do you do?',
    'What one word in the English language would you like to lock in a box before '
    'throwing away the key?',
    'Would you know what to do if you saw someone choking? Have you ever had to '
    'do it?',
    "If your child's goldfish died, would you replace it with another and pretend "
    "it hadn't?",
    'Do you believe there is life more intelligent than humans in the universe?',
    'How many of your childhood friends are you still in touch with today?',
    'What childhood belief (lost in adulthood) is most special?',
    'If you could choose one thing to give as a gift to an unknown newborn baby, '
    'what would it be?',
    'What makes someone a genius?',
    "Your roof has just sprung a leak. What would be the first thing you'd grab "
    'to catch the drip?',
    'If you could be teleported to any destination in the world, where would it '
    'be?',
    'What might be a fun alternative to the waiting expression, "until the cows '
    'come home"?',
    'Have you ever exercised at home with a fitness video? What was the name of '
    'the workout?',
    "If a fly wasn't called a fly, what would be a more creative name for it?",
    'What was the last thing that gave you a static shock?',
    'Before Google, where did you find information?',
    'What loud noises bother you most?',
    'If you could choose the view from your office, what would you like it to be?',
    'What three animals would you like to add to a box of animal crackers?',
    'If you were a food critic, which restaurant would you like to visit first?',
    "What's your favorite font?",
    'Have you ever slid down a bannister? When was the last time?',
    "How many inflated balloons do you think you could fit in the room you're in "
    'now?',
    'lf you had spare cash to buy something just for fun today, what would you '
    'buy?',
    'Other than a bath, what was the last thing you dipped your toes into?',
    'When was the last time you started a conversation with a stranger?',
    'If a movie of your life was made, who should be the director, and why?',
    'What movie is overrated?',
    'Do you have a special key chain? If so, where did you get it?',
    'Which sportsperson could just about everyone around the world name from a '
    'picture?',
    'What one day in your life would you like to relive?',
    'Have you ever been caught telling a lie?',
    'When and where did you last see a rainbow?',
    'If a snowstorm is a “whiteout," what color of “out" should a rainstorm be?',
    'For Gollum it\'s a ring, but what would you call "my precious"?',
    "What's the best outfit you've ever worn to a costume party?",
    'You are a thoroughly modern witch. What do you have instead of a broomstick '
    'and black cat?',
    "Would you have your dominant thumb surgically removed if it meant you'd be "
    'immune to all known diseases?',
    'In a game of Monopoly, what property do you always try to buy first?',
    "You're given $1,000,000 to invest. Where and how do you invest it?",
    "What's the best purchase you've made on eBay?",
    "Whistles instead of words? What's the most unusual means of communication "
    "you've heard of?",
    'Where would you go on a dream day out?',
    'If you could talk to one animal, what one would it be and why?',
    'Under what circumstances would you consider euthanasia for a beloved family '
    'pet?',
    'What city, state, or country name would make the silliest celebrity baby '
    'name?',
    'If you could choose your seat on a long-haul jumbo jet flight, where would '
    'you sit, and why?',
    "What's the craziest thing you've timed yourself doing?",
    "Your nose starts to run in public, but you don't have a tissue: what do you "
    'do?',
    "What's your favorite fairground ride and why?",
    "The bridge connecting you to the nearest town is destroyed and you don't "
    'have gas to make the detour. What do you do?',
    "What's the longest book you've ever read?",
    'If you were a genie, but not in a lamp, where would you be and how could you '
    'be summoned?',
    'What one word would you use to describe your best friend?',
    'Should all city centers become traffic-free zones?',
    "What was the last thing that happened that made you think you'd dodged a "
    'bullet?',
    'Have you ever pretended not to be in when someone came to your door?',
    'Who was there?',
    "We've had Edward Scissorhands, but what else would make good substitutes for "
    'hands?',
    'What three examples describe your favorite color?',
    "If a stranger said they'd pay you $100 for a selfie with you, would you do "
    'it?',
    "What's the harshest truth you've ever been told?",
    'When was the last time you spoke to your neighbors? Do you know their names?',
    'Did a teacher ever write anything on your school report that you went on to '
    'prove wrong?',
    'Which sport should not be classified as a sport?',
    'If you had the afternoon off work (or school) at short notice, what would '
    'you do with the time?',
    "What's the worst thing you've eaten or drunk by mistake thinking it was "
    'something else?',
    'Which actor is in real life most like the character(s) they play?',
    'What makes someone a legend?',
    'In a game of Trivial Pursuit, what category is your strongest?',
    'If you could go back in time, would you attend college? Why?',
    "When you bump into a stranger, what's your first reaction?",
    "What's the funniest misspelled tattoo story you've heard?",
    "Kangaroos can't move backwards. How would it affect your day if you "
    "couldn't?",
    'Have you ever drooled in public?',
    'If you could choose your siblings, would you have brothers or sisters?',
    'Would you give up one year of your own life if it meant your pet could live '
    'for another year?',
    "What's the craziest sound you've heard a bird imitating?",
    'How many gummy bears can you fit into your mouth?',
    'If you had time to volunteer for a charity, which one would it be?',
    'What\'s your favorite expression to describe someone who is "not the '
    'sharpest tool in the shed"?',
    "Do you check people's social media accounts to learn more about them? Who "
    'was the last person you checked?',
    "What's the biggest favor you've asked someone to do for you?",
    'Other than family, do you know anyone who has the same family name as you?',
    'If astray dog followed you home, would you take it in?',
    'Before going to sleep tonight, what three things about today will you be '
    'most grateful for?',
    "You're in a meeting room for a job interview but the interviewer hasn't "
    'shown up after thirty minutes. What do you do?',
    "What's the best prank you've pulled on someone?",
    "You've won an all-expenses-paid trip but you've just sixty seconds to choose "
    'a destination. Where would you choose?',
    "If you're unhappy with your current weight, what would your ideal weight be?",
    'What character from Sesame Street did you (or do you) love the most, and '
    'why?',
    'Do you have an archnemesis? Who is it?',
    'When was the last time you smiled at a stranger?',
    '60s, 70s, 80s, 90s, 00s, 10s: Which decade did you love the most and why?',
    "In a movie of your life, what soundtrack would convey the mood of today's "
    'events?',
    'How many high school sweethearts do you know who got married and stayed '
    'together?',
    "What's guaranteed to give you gas or indigestion?",
    'Have you ever played Dungeons and Dragons?',
    'What was the last molehill that you made into a mountain?',
    'If a time-traveler from fifty years ago arrived in the world today, what '
    'would disappoint them?',
    'When and why do you like to be alone?',
    'What\'s a good example of "just because it\'s popular doesn\'t mean it\'s '
    'good"?',
    'On a scale of one to ten (with ten the healthiest), how healthy is your '
    'diet?',
    "We've had generations X, Y, and Z; what generation is next?",
    'If a year of your life could be traded for $25,000, how many years would you '
    'trade in?',
    'Which six people would you want to be stranded on a deserted island with, '
    'and why?',
    'Have you ever snuck into anywhere without paying?',
    'If aliens landed, where would you take them first on a whistle-stop tour of '
    'life on Earth?',
    'How many male-female singing duos can you name?',
    'What three foods would taste better if they were dipped in chocolate?',
    'You are an indestructible cartoon character and are falling from an airplane '
    'without a parachute. What will happen next?',
    "What's your favorite expression that describes feeling very tired?",
    'Would you give a hitchhiker a ride?',
    'What would you like your spirit animal to be?',
    'If you could snap your fingers and be any height, would you choose to become '
    'taller or shorter?',
    'Do you always walk around supermarket aisles in the same order?',
    'What childhood award or prize are you most proud of winning?',
    'Ahundred years from now, how would you like to be remembered?',
    'Who deserves the title of "biggest sports cheat"?',
    'Which actor would be the most ridiculous choice for the role of Indiana '
    'Jones?',
    'If you had to answer questions on your specialist subject, what would the '
    'subject be?',
    'What makes someone a nerd?',
    'Have you ever been disappointed by a hotel room that looked nothing like the '
    'brochure?',
    'What would you do if you saw a colleague steal something from your '
    'workplace?',
    '172. \\Nhen was the last time you shared a bath with someone?',
    'Under what circumstances would you say it’s better to be safe than sorry?',
    'What one word yelled in a public place would cause the most chaos?',
    "If you're waiting for your ship to come in, what's on that ship?",
    "What's the last thing you do before you go to sleep at night?",
    "177. You've won a two-week cruise for two. Who would you take with you?",
    'What would happen if everyone on Earth jumped at the same time?',
    'Do you know what every button on your TV remote control is for?',
    'Which shade of beige is your favorite, and what creative name can you give '
    'it?',
    'What would be a good name for a fifth musketeer?',
    'If you had to arm wrestle the person sitting closest to you now, would you '
    'win?',
    "What's the most irksome challenge you deal with in daily life?",
    'Where would you absolutely refuse to go alone?',
    "The Japanese have a word for gathering books that you're unlikely to ever "
    'read. What word would you use?',
    'If all but one Christmas song should be banned, which one should be kept?',
    'Have you ever spoken up for someone else? What was it about?',
    'What will you do for your pets that you will not do for other family '
    'members?',
    'Other than having a cold, what makes you sneeze?',
    'What was the last item you put in your basket on Amazon?',
    'lf you could create a new martial art, what would you call it?',
    "What's your favorite Elvis song? If you don't have one, why not?",
    'Should breakdancing be an Olympic sport?',
    "Hippocampus hippocampus is a seahorse. What's the weirdest scientific name "
    'for something you know?',
    'What were you doing the last time you questioned your sanity?',
    'If you had to attach a “most likely to..." to three of your friends, what '
    'would they be?',
    'Knowledge is power: what do you wish you were more knowledgeable about?',
    "What's the worst thing that's happened to you in a fitting room?",
    'If you were a ghost, who would you haunt for fun?',
    'What things should you pay more attention to than you do?',
    '‘Ina parallel universe, what might be going on in Area 51?',
    'Would you ever consider shaving your hair off to raise money for charity?',
    '203. Do you avoid walking under ladders? Why?',
    'What three foodstuffs are must-haves in a picnic?',
    'If alljobs paid the same salary, would you change your career?',
    "What's the most ridiculous way you've managed to injure yourself?",
    "~Have you ever squeezed a pimple on someone else's body?",
    "What's the scariest storm you've been in?",
    'When was the last time you screamed out loud, and why?',
    'The immortal hero in your novel can only be killed by one thing. What '
    'everyday thing is it?',
    '211. ~What task would you least like to have to do alone?',
    'Have you visited a national park? Which one(s)?',
    "213. What's your preferred backup option for data? Why?",
    'What characters might Alice in Wonderland have met in a parallel universe?',
    'When did you first feel like a grown-up and what were you doing?',
    'If you could customize your car, what would you add?',
    '217. Do you believe that no one is indispensable in the workplace?',
    'What sound would you least like to hear if you were home alone at night?',
    'Have you ever slept in a sleeping bag? When was the last time?',
    'What smells make you gag?',
    'If you were a giant garden gnome, what pose would you be in?',
    'Which Scooby-Doo character are you most like?',
    'What score out of ten would your friends give you as a dancer?',
    'How many of your Facebook friends are people you physically spend time with '
    'regularly?',
    'What one item do you always carry with you "just in case"?',
    "You've turned into the main character in the last TV show you watched. Who "
    'are you?',
    "What's your favorite Disney movie? If you don't have one, why not?",
    'lf you had to be a leader of something, what would it be?',
    "What's your preferred non-dairy milk alternative?",
    'If you could only choose one pie for Thanksgiving, sweet or savory, what '
    'would it be?',
    "We've had laptops and palmtops, so what should we have next?",
    'Is it possible to forgive and forget?',
    'If all the countries became one united country, what city would become '
    "Earth's capital?",
    "What's the hardest physical work you've ever done?",
    'Would you eat squirrel meat? Have you tried it?',
    'Which prize would you choose: a $200,000 luxury car or $200,000 cash?',
    'How many hours of TV do you watch in a typical week?',
    'Have you ever dressed in the national costume of another country? Which one?',
    'If your best friend was granted three wishes, what do you think they would '
    'be?',
    "What's the highest calorie food you could carry with you to fuel a two-day "
    'mountain hike?',
    'How much money would entice you to gain a hundred pounds and keep it on for '
    'at least one year?',
    'Which optional herbs or spices do you always leave out of a recipe and why?',
    "What's the ickiest thing you've ever accidentally sat on?",
    'You are blindfolded and must visit the place you pin on a map. Where would '
    'you hope not to pin?',
    'What was the last new word you learned?',
    'lf you could design a coat of arms for your family, what symbols would you '
    'include?',
    "What's the most amazing thing you've seen in a slow-motion video?",
    'Which actors have become typecast?',
    'What makes the best breakfast ever?',
    'If you had to be an insect, which one would you be, and why?',
    "What's the worst thing you could be wearing if you were rushed to the ER?",
    'How many people do you follow on social media?',
    'What new flavor of cotton candy would you like to create?',
    'When was the last time you sat on a teeter-totter/seesaw?',
    "What's the strangest cultural tradition you've learned of?",
    'If all the lights in your home and street suddenly went out at night, what '
    'would you do?',
    'Do you ever accept second best?',
    'What three ingredients do you need to make a great-tasting smoothie?',
    "Other than KFC, what else is finger lickin' good?",
    'What music festival would you most like to go to?',
    'If you were a high-dive champion, what new dive move would you invent and '
    'what would you call it?',
    'Which sci-fi movie best predicts the future of life on Earth?',
    'What modern gadget would make a great steampunk creation?',
    'Who did you last play frisbee with, and where?',
    "What's your favorite cookie to have with milk?",
    'If all your thoughts so far today appeared as text above your head, how many '
    'people would you have offended already?',
    'What memory of you as a kid does your family like to embarrass you with by '
    'telling everyone?',
    'Have you ever experienced a deafening silence?',
    "What's the last thing you do before leaving your home to go away for a few "
    'days?',
    'If your birthday could be on a different date, which one would you choose, '
    'and why?',
    'What childhood toy do you still have today?',
    'Using your MacGyver-like skills, what could you use to escape from a flooded '
    'underground tunnel?',
    'Helen Back? Ben Dover? What unfortunate and funny name combinations have you '
    'heard of?',
    "Would you eat packaged food that's passed its expiration date?",
    "You've spilled red wine on a white carpet: what do you do?",
    'If you could do one magic spell, what word would you say as you waved your '
    'wand?',
    "We've had Snakes on a Plane, so what would you like to put on a plane next?",
    'The last meal you ate will become an art installation. What will you call '
    'it?',
    'What inanimate object have you seen a face in? Was it a famous face?',
    'In a twenty-first-century revamp, what new names should be given to Velma, '
    'Daphne, and Fred in Scooby-Doo?',
    'Did the tooth fairy visit your home when you were little?',
    'What has happened in your life that you never thought would?',
    'When was the last time you sat in silence?',
    "\\f Alvin the chipmunk wasn't called Alvin, what name should he have?",
    'If you had to be without one sense (sight, sound, taste, touch, smell) for a '
    'day, which would you choose?',
    'What game for one player do you like to play?',
    "Have you ever sneaked a peek at someone else's journal?",
    "What was the last picture you took that wasn't a selfie?",
    'If you could master any skill or talent, what would it be?',
    "Have you ever played a pifata game and what's your best pifiata story?",
    'Should all things Christmas be illegal until December first?',
    "What's the most annoying thing you've forgotten to do more than once?",
    'How many people do you hug in an average day?',
    "If an orange didn't share its name with its color, what would you call it?",
    'Do you ever drink iced coffee or tea in the winter?',
    "What's your favorite Clint Eastwood movie? If you don't have one, why not?",
    'If you were a landscape artist, what landscape would you most want to paint?',
    "What's the most awesome thing you've known people be able to do with their "
    'feet in place of their hands?',
    'Which room in your home do you spend the most time in?',
    'Like February 29th, what other day do you wish only came around every four '
    'years instead of every year?',
    'What three performers (alive or dead) would you like to see perform together '
    'on stage?',
    'If you could earn a PhD in the subject you happen to know most about right '
    'now, what would it be in?',
    'What food looks way better than it tastes?',
    'Have you ever pretended a store-bought cake was homemade?',
    'Remember soap on a rope? What new thing would you market on a rope?',
    'What facial expression do you have that speaks volumes without you saying a '
    'word?',
    'If your first name was an acronym, what would the letters stand for?',
    'Where would be the worst place to have a heart attack?',
    'What color do you most associate with holidays?',
    'Have you ever stockpiled food or household items in case of shortage?',
    'What other colors would you like pandas to come in?',
    'If you had to build something that could be seen from space, what would you '
    'create?',
    'What food should always be bought fresh, not canned or frozen?',
    'Do you believe anything is possible and nothing is impossible? If not, why '
    'not?',
    'Would you eat a beetle on a dare?',
    'In a twenty-first-century version of Hansel and Gretel, what might they '
    'leave a trail with instead of breadcrumbs?',
    'What ingredients make the best ice cream float?',
    'Have you ever been heartbroken? What happened?',
    'What habit is the most annoying?',
    'When was the last time you said, "Why me?" and what prompted it?',
    "You've only thirty seconds to recite the alphabet backward or the fluffy "
    'bunny gets it. Could you do it?',
    "What's the most creative excuse for being late you could invent and get away "
    'with?',
    'Can long-distance relationships work?',
    'If you could eat your plates instead of washing them, what would you want '
    'them to taste like?',
    "You arrive at work and realize you've forgotten your packed lunch. What do "
    'you do at lunchtime?',
    'What color has gone out of fashion most recently? Are you still wearing it?',
    "327. Other than lemonade, what's the best thing you can make with lemons?",
    "What's your least favorite Christmas carol?",
    'If you had to compete for your country in a sport tomorrow, which one would '
    'you do best (or least bad) in?',
    "What have you argued for in the past that really doesn't matter to you "
    'anymore?',
    '331. Which ravioli filling is your favorite?',
    "What's the sound of summer?",
    '333. Has asmall act of kindness ever had a big impact on you?',
    'What was the last question you asked your smart speaker?',
    'What are your favorite items to purchase from a farmers market?',
    'What job is the ideal first job for teenagers?',
    'If asked to describe your day so far in three words, what would you say?',
    'Hippos wallow in mud. What would you most like to wallow in?',
    'ATV network wants to interview you for a feature about your employer. What '
    'do you do?',
    "What's the most creative thing you could make with an old newspaper?",
    'Whodo you count on the most for help?',
    'Which ancient monument would be the saddest loss to the world if it crumbled '
    'to dust?',
    'If you were a news anchor, what breaking news story would you most like to '
    'read out?',
    'What might be an alternative ending to the story of Little Red Riding Hood?',
    'Do you believe in angels? Have you seen one?',
    'What\'s the worst thing that could be made into “leftovers pie"?',
    'If your friends had to give you a nickname that summed up your attitude, '
    'what would it be?',
    'What movie prop would you most like to own?',
    'Have you ever eaten so much that you had to lie down to ease the discomfort? '
    'When was the last time?',
    'What three reasons do you have to be cheerful today?',
    'How many people do you know with the same first name as you?',
    'When was the last time you said, "That\'s cool!”?',
    'What mythical beast would you most like to be real?',
    'Visitors to your town want to know a good place to eat. Where would you send '
    'them?',
    "Would you eat food you didn't recognize without asking what it was? Have you "
    'done that?',
    "What's the strangest cult you've heard of?",
    '«If you had to convey your anger without making a sound, how would you do '
    'it?',
    'Are all the clocks in your home twenty-four-hour digital clocks?',
    '~Have you ever struggled to do something that was promoted as “idiot- '
    'proof"? What was it?',
    "What's your favorite cake frosting?",
    '361. When did you last “party like it\'s 1999"?',
    "What's the smallest thing you've seen in nature?",
    "You've invented a new super-strength industrial adhesive. What will you call "
    'it?',
    'What might Butch Cassidy and the Sundance Kid be called in a parallel '
    'universe?',
    'If you could flip a switch and a household chore would be done, which chore '
    'would you want it to be?',
    'What smells do you find relaxing?',
    "The number of weddings and funerals you've been to becomes the title of a "
    "movie. What's the title?",
    'What children’s story character used to scare you when you were a child?',
    'In a twenty-first-century update, what items might your true love receive '
    'over the twelve days of Christmas?',
    'Which radio station do you listen to most often?',
    'What pet names do you have (or have had) for private body parts?',
    'For how long would you give chase if your umbrella got taken out of your '
    'hand by the wind?',
    'How many fries would make a fair trade for a chicken nugget?',
    'What older celebrity looks better now than they did when they were younger?',
    "If baboons didn't have blue bottoms, what color would make a fabulous "
    'alternative?',
    'Have you ever struggled to open “easy open" packaging?',
    'What was the last thing that made you itch?',
    'If you had to compile a top ten list of your favorite pies, which one would '
    'get the number one spot?',
    'What makes the best wedding outfit?',
    'Do you believe that everyone has a look-alike somewhere in the world? Have '
    'you met any?',
    'What other words do you use for a “thingamajig"?',
    'Should ancient human remains displayed in museums be returned to their '
    'homeland?',
    'If bubble gum was savory, what flavor would you like it to be?',
    "What's the saddest headstone or grave marker you've ever seen?",
    'When was the last time you said, "That sucks!"? Why?',
    "What's the weirdest sport you've played?",
    'If you had to delete all but three pictures from your phone, which three '
    'would you keep?',
    'What three songs are you most likely to sing in the shower?',
    'Do you listen to podcasts? What have you listened to most recently?',
    'What songs are on your “let\'s get this done" soundtrack?',
    'Would you describe yourself as a hard worker, and what are you working hard '
    'on now?',
    "What's your favorite Bruce Springsteen song? If you don't have one, why not?",
    'If you were a pirate captain, what would you name your ship?',
    'What subject taught in school have you used most in life outside school?',
    'Other than money, what else do you wish grew on trees?',
    'Where would be the most annoying place to have a boil?',
    "What's the strangest phobia you've ever heard of?",
    'If Buddy Holly had survived the plane crash, what might the title of his '
    'next hit song have been?',
    'What thing that your parents always warned you about turned out to be good '
    'advice?',
    'You can have an unlimited supply of one type of candy for the rest of your '
    'life. What will you choose?',
    "What's the worst thing that could happen while you're brushing your teeth?",
    'If you could gain a qualification today, what would you like it to be?',
    'Have you ever wished you were older?',
    'What color of car do you least like?',
    "You've invented a new energy source. What is it and what will you name it?",
    "What's the silliest thing you've cried over recently?",
    "Like Sleeping Beauty, you've fallen into a hundred-year sleep; what will "
    'change most in the world before you wake up?',
    'What were the choices the last time you had to flip a coin?',
    "Do you ever give up on reading a book when you're already halfway through?",
    'Which popular movie needs a different title, and what title would you give '
    'it?',
    'If your friends had to meet you in a bookstore, in what section would they '
    'look for you?',
    "What's the one thing you don't want people to say when you've just broken up "
    'with someone?',
    'Which animal is the deadliest in the world?',
    'ModelLand has opened in California. What theme park would you like to open?',
    'If cartoon characters had rap careers, who would be the best?',
    'What will Earth look like ten thousand years from now?',
    'Who do you find it difficult to feel sorry for?',
    'Have you ever tidied up a room by stuffing everything into a closet?',
    'When was the last time you said, "Bring it on!" and why?',
    'What would be a funny message to paint on the underside of your boat?',
    'Cat-opoly? What make-your-own-opoly board would you create?',
    "Have you ever experienced buyer's remorse? If so, what was the purchase?",
    'What would be the most inappropriate drive-thru?',
    'If you could get a shopping cart full of food and drink for free, what would '
    'you put in it?',
    "What's the most unusual thing you've ever used as a bookmark?",
    'When did you last behave selfishly? How?',
    "Mr. Baker the baker? What's the funniest example of a person's name fitting "
    'their job?',
    "What's your favorite brand of gum and why?",
    'If you were a salad, what type of dressing would be the best match for you?',
    'What was the last thing that made you laugh out loud?',
    'Do you have an item of jewelry that you never take off? What is it?',
    'What "buy one get one free" would be of absolutely no use to you?',
    'On a scale of one to ten, how embarrassing is your passport photo?',
    "What's the oddest thing you've ever seen in a museum?",
    'Would you dance differently if you thought no one was watching?',
    'If cats came in every color, would you choose one that matched your home '
    'décor?',
    "What would you do if you had to poop in someone else's house and it wouldn't "
    'flush?',
    'Have you ever toasted marshmallows on an open fire? When was the last time?',
    'The Olympics are coming to your hometown and you need to design a mascot. '
    'What will it be?',
    "A home makeover show decorates your bedroom: what's the worst color scheme "
    'they could use?',
    'In what decade would you most like to have been a teenager?',
    'What color Power Ranger would you be?',
    'How many European capital cities can you name?',
    'Which pop princess would make the most ridiculous lead singer in a heavy '
    'metal band?',
    'What would you like to take lessons in?',
    'If you had to describe your personality as a smell, what would it be?',
    'What one stupid thing you did as a teenager are you most embarrassed by now?',
    "You've invented a new board game. What are your playing pieces?",
    'What three songs have been on your playlist for the longest time?',
    'Other than playing table tennis, what are two other uses for a table tennis '
    'ball?',
    "If Charlie's Angels was remade with an all-male cast, who should play the "
    'lead roles?',
    'What makes the difference between living and existing?',
    'Have you ever experienced déja vu?',
    'What would your team name be if you and your friends went bowling?',
    'If cobwebs were colorful, would you still dust them away?',
    "What's the oldest thing in nature you've seen?",
    'When was the last time you put on a brave face but were dying inside?',
    'Where were you shopping and what were you buying when you last experienced '
    'excellent customer service?',
    'If you could get free season tickets for any team in any sport, what would '
    'you get?',
    "What's your favorite board game?",
    "Do you ever keep your New Year's resolutions?",
    'Would you consider being frozen (cryogenics) and brought back to life in the '
    'future?',
    'How many people do you know (personally) with a name that begins with B?',
    "What's the best bargain you've picked up in a sale?",
    'If cockroaches could talk, what would they say and sound like?',
    "What's the worst parking you've seen, and where was it?",
    'You can only eat one type of bread for the rest of your life. What type will '
    'you choose?',
    "What's been the easiest money you've ever made?",
    'If you could give anyone a radio shout-out right now, who would it be?',
    "What's the strangest room you've ever been in, and why were you there?",
    'Should animals have the same rights as humans?',
    'In a twenty-first-century version of the Wizard of Oz, what might Dorothy '
    'wear instead of ruby-red shoes?',
    'What was the last thing that made you say, "Wow!"?',
    'Which planet in our solar system would you most like to visit?',
    "What's the oddest thing you keep in the trunk of your car?",
    'Have you ever been in a burping contest, and did you win?',
    "What's the best optical illusion you've ever seen?",
    'If dinosaurs were reintroduced, where in the world today would be their '
    'ideal habitat?',
    "Can you remember the words to the children's song “Frére Jacques”?",
    'In what general knowledge quiz category is your knowledge generally not that '
    'great?',
    "What's the best way to recover after being left hanging for a high-five?",
    'Have you ever been convinced someone was telling you a lie and it turned out '
    'to be true? What was it?',
    'What color would make a black hole more inviting?',
    'How many gadgets do you have at home that beep at you?',
    "What's the most wasteful thing that you do?",
    'If you had to describe your week so far through the medium of dance, what '
    'dance would it be?',
    'Which app on your phone is the most useful, and which is the most useless '
    'but fun?',
    "If your goal is world dominance, what's your first step?",
    "What's the most useless superhero power?",
    "You've invented a fastener to take over in place of Velcro (hook and loop): "
    'what is it?',
    "What's your favorite ABBA song and do you know all the lyrics?",
    'When did you last eat alphabet pasta and what words did you create?',
    'lf you could get ten tickets to anything you wanted, what would you choose '
    'and who would you bring?',
    'What three things are essential in making a dream treehouse?',
    'Have you ever stood in a long, long line to buy something? What was it?',
    'When was the last time you pushed a door labeled “pull"?',
    "What's the coolest website you've stumbled upon that no one seems to know "
    'about?',
    'If your hair could be any color for one day, what would it be?',
    'Who do you know that has been married the longest? How many years?',
    "Would you burn McDonald's burger-scented candles in your home?",
    'If Elvis was still alive today, what would he be wearing?',
    "What's the funniest thing you've heard a child innocently blurt out?",
    'Mashed potato? Twist? What old-school dance moves do you know?',
    "What's the funniest super glue incident you've heard of?",
    'Do you believe that a full moon can affect people’s behavior? Why?',
    "What's the greatest threat to humanity?",
    'Hot Dog High is an actual place: do you know anyone who has applied to drive '
    'a “wienermobile"?',
    'In what location would you most like to sleep under the stars?',
    'Have you ever been in a food fight?',
    "What's the oddest sight you've ever seen?",
    'lf you were a spy, what would your code name be?',
    "Other than the sun, what's the hottest thing you've seen in nature?",
    'What “did you know?" fact do you keep at the ready to get a conversation '
    'started?',
    'Monday morning blues? What new word can you come up with to describe that '
    'Monday morning feeling?',
    'Given the choice, what color and design of front door would you have?',
    'What one song would you like the whole world to be able to sing?',
    'Have you ever done something just to impress someone else? What was it?',
    "What's the worst tattoo you've ever seen on someone?",
    'Where were you and what were you doing the last time you felt totally '
    'relaxed?',
    "What's the laziest thing you've ever done?",
    'The paparazzi mistake you for someone famous and surround you with cameras: '
    'which celebrity is it and what do you do?',
    'What color would the big red button need to be to make you less inclined to '
    'push it?',
    "Not housewife, domestic goddess. What's the best description you can come up "
    'with for the most mundane job?',
    'What was the last thing that really grabbed your attention?',
    "Are you happy when you're alone?",
    "What's the most dangerous job or career?",
    'Which part of your body has the highest value for insurance purposes?',
    "What's the most unusual or odd-shaped building you've been in?",
    'If you could go back in time to see a brand-new invention being unveiled, '
    'where would you go?',
    'What three things are you good at?',
    "You've fallen at home and can't get up. Would you drink from the dog's bowl "
    'to avoid dehydration?',
    "What's the funniest thing you've overheard?",
    'When was the last time you polished your shoes?',
    "What's your favorite “until you're blue in the face” expression?",
    'On ascale of one to ten, how good would you say your handwriting is?',
    'What makes the ideal workout?',
    'How many people in your family can curl their tongue and are you one of '
    'them?',
    "What's the funniest cheesy country song title you've ever heard?",
    'Would you be happy to travel in a driverless car?',
    'If you had to display a full suit of armor in your home, where would you '
    'position it?',
    "What's the most fun thing you've ever found inside a Christmas cracker?",
    "Have you ever fallen asleep somewhere you shouldn't have? Where was it?",
    'Do you catch the news every day? What headline caught your eye today?',
    "What's the funniest pet cat name you've ever heard?",
    'You can only have one type of flooring in your home: what will you choose?',
    'Have you ever told ghost stories around a campfire and what were they?',
    "What's the most politically incorrect thing you've said or done recently?",
    'Could you explain in three steps how to make a cup of tea to someone who has '
    'never done it?',
    'Which one of your senses would you most like to have magnified to super- '
    'strength?',
    'Have you ever farted in a jar to keep it as a pet?',
    'If you had to draw a picture right now, what would you be most likely to '
    'draw?',
    "What's the most ridiculous warning sign you've ever seen?",
    'How many foods can you name that begin with the letter R?',
    'When did you last feel bored?',
    'If you were a squirrel, where would you hide your nuts to stop others '
    'stealing them?',
    "What's your all-time favorite dip?",
    'Should athletes be allowed to use performance-enhancing technology?',
    'What\'s your favorite "just add water” thing?',
    'In what one way do you feel you differ most from your parents?',
    'What crazy fitness trend would you like to start?',
    'Do you ever push harder and harder on the remote-control buttons, even '
    'though the battery is dead?',
    "What's your best “why did the chicken cross the road” joke?",
    'When was the last time you performed a random act of kindness and what was '
    'it?',
    "What's the most unusual animal you've held in your hands or touched?",
    'If your hands were tied behind your back, could you get your socks on?',
    'Who do you know that you would describe as a “character” and why?',
    'What was the last thing to make you face palm?',
    "Have you ever been in a situation where you just didn't know what to say?",
    'What happened?',
    "What's the one thing that you and your friends can never agree on?",
    'If you could go on a dinner date with anyone (dead or alive) tonight, who '
    'would it be?',
    "What's the most unlikely thing to hear a news anchor say?",
    'Other than Uncle Buck, do you know anyone who microwaves their socks?',
    "What's the most ridiculous thing you could stuff a mattress with?",
    'How many people would you share a password with?',
    "If ethics weren't an issue, what mad scientist experiment would you like to "
    'trial on humans?',
    "You've discovered the secret to eternal youth: what is it?",
    "What's the most outdated expression you still regularly use?",
    "Goat yoga? What's the weirdest type of yoga you've heard of or tried?",
    'If your index fingers suddenly doubled in length, how would it affect your '
    'day?',
    "What's the funniest home video you've ever seen?",
    'Would you allow two elderly adults to die if it meant one child would be '
    'saved?',
    "What's the most sexist thing anyone has ever said to you?",
    'On ascale of one to ten, how much do you like pumpkin pie?',
    'Where were you and what were you doing the last time you felt nervous '
    'walking into a building?',
    'If you could have a famous band play at your funeral, who would it be?',
    'What three things are you most grateful for in your life?',
    'Have you ever pretended to be an answerphone message?',
    'What "pick and mix” or penny candy items do you always pick first?',
    'lf you had to describe yourself as a book genre, what would it be?',
    'What other colors would you like white fluffy clouds to come in?',
    'Did you bounce on the bed when you were a kid?',
    "What's the most unbelievable thing you've ever heard someone say?",
    'Which one of your relatives is most likely to embarrass you at a family '
    'gathering?',
    'If everything you ate tasted the same, would you still eat a variety of '
    'foods?',
    'Do you have a secret hunch about how you will die?',
    'Have you ever been lost in a maze?',
    "What's the most exciting thing you've ever found in the least exciting "
    'place?',
    'Do you ever read the last page of a book before getting to the end?',
    "What's the most tedious part of an average day for you?",
    'If given the opportunity, would you do a parachute jump?',
    'When was the last time you owed someone money?',
    "The person you're standing next to on a crowded train has bad body odor. "
    'What do you do?',
    'What creative use can you come up with for a single glove?',
    'In what way would your life be better if you had x-ray vision?',
    'What makes the most satisfying sound?',
    'How many pieces were there in the biggest jigsaw you ever completed?',
    "What's the most stupid cause of accidental death you've heard of?",
    'Would getting rid of "likes" on social media help reduce anxiety?',
    'Have you ever felt like a big fish in a small pond? When?',
    "What's the worst gift you've ever received?",
    "Do you celebrate Thanksgiving, and what's at the center of your "
    'celebrations?',
    'What common occurrence in movies rarely happens in real life?',
    "If grass wasn't green, what color would you like it to be?",
    'You can only keep one electrical appliance in your kitchen: which one will '
    'you choose?',
    "What's the funniest explanation of how babies are made that you've heard?",
    'How many pink things can you list in the next ten seconds?',
    "What's the longest distance you've ever jogged?",
    'If you were a storm chaser, what type of storm would you most like to chase?',
    'What was the last thing to make your fingers sticky?',
    'Have you ever been on a blind date?',
    "What's the first thought that goes through your mind when you see a homeless "
    'person?',
    'If you could have a home in a different country, where would it be?',
    'What alternative uses have you found for a handkerchief?',
    'When did you last jump in a puddle?',
    "You've developed a new brand of cat food. What's its name?",
    "What's your biggest worry right now?",
    'Do you like marmalade sandwiches as much as Paddington Bear does?',
    "What's the craziest gadget you've seen advertised on a teleshopping channel?",
    'Have you ever pretended not to know something? What was it?',
    'With what items do you always go for quantity over quality?',
    "If gravity suddenly didn't exist, what would you hit on the way up from "
    'where you are right now?',
    'What three things are you most looking forward to this year?',
    'If your initials are the name of a new deadly virus, what would the name be '
    'and the symptoms?',
    "What's the best thing you've found down the back of your sofa?",
    'Other than water, what would you most like to jump into a pool of?',
    'When was the last time you made yourself dizzy?',
    "What's one useless general fact or nugget of trivia you know?",
    'How many rooms are in your dream house, and what are they all for?',
    'If you had to eat a crayon, what color would you choose?',
    'Do you listen to any music today that your parents listened to when they '
    'were your age?',
    "What's the most ridiculous rule you've ever had to follow?",
    "If Greyhound Lines hadn't chosen the greyhound, what would make a great bus "
    'logo?',
    'Who do you know who can never keep a secret?',
    "What's the dumbest way you've heard of a criminal being caught?",
    'If you could have a life-sized model of any animal in your home, what would '
    'you have?',
    'Which one of your friends is most likely to invent something useful?',
    'Where were you and what were you doing on the hottest day you can remember?',
    'If you were a superhero by night, what day job would you have to protect '
    'your identity?',
    'Which bit of a trifle is the best?',
    'Should bands stop going on world tours to help save the environment?',
    "What's a good name for a fear of hot dogs?",
    'Have you ever been on a Ferris wheel? What could you see from the top?',
    'What crime is the most evil of all?',
    'If humans became caged exhibits in zoos, what habitat would they be housed '
    'in?',
    'What is the most adventurous outdoor activity you would attempt?',
    'Has anyone ever accused you of being the Grinch? Why?',
    'What would you most like to be the leader of?',
    '|f you had to eat dessert for breakfast, what would you have?',
    'What was the last thing you asked Santa Claus to bring you?',
    'Easier said than done? What do you find easy in theory but difficult in '
    'practice?',
    "What's the worst lie you've ever told?",
    'If your kettle could speak, what would it say as it boils?',
    'What would you do if you found twenty dollars in a hotel room drawer?',
    'Do you name your car, and what other objects in your life have you named?',
    "What's your best waterslide story?",
    'Would you allow an animal to die to save a person?',
    'Instead of “one small step ..." what would be a funny alternative Neil '
    'Armstrong moon-landing quote?',
    'What would be the worst thing you could say on a first date?',
    'Have you ever tried to burp the alphabet? How far did you get?',
    'What makes the perfect pop song?',
    'Do you care what other people think about you?',
    "What's the most ridiculous reason for a couple breaking up that you've heard "
    'of?',
    'If your life depended on leaping across an eight-foot gap between high '
    'rooftops, would you attempt it?',
    'Which accent do you find sexiest?',
    'A spoon and fork combo is a spork. What other utensil combo could you create '
    'and what would you call it?',
    'When was the last time you made someone a cup of tea?',
    "You've cultivated a new type of vegetable. What is it and what do you call "
    'it?',
    'What would be the hardest thing about living in a lighthouse?',
    'If you had to fake your own death, how would you do it?',
    "What's the dumbest reason for going to the ER you've heard of?",
    'Which one of your friends or family has the neatest handwriting?',
    'Have you ever tried to check if the light goes off when you close the fridge '
    'door?',
    'What would be a great name for a new gym?',
    "Do you have an old pair of socks that you can't bear to part with?",
    'What word starts to sound weird the more you say it?',
    'Have you ever tried to lick your elbow?',
    "What's the most ridiculous celebrity baby name you've heard?",
    'If you could have a private cookery lesson with a chef, which cuisine would '
    'you choose?',
    'Winnie-the-Pooh needs a makeover. How will you dress him?',
    'What was wrong with you the last time you were ill?',
    'On a scale of one to ten, how reliable would your friends say you are, and '
    'why?',
    'What crossword cryptic clue are you most proud of solving?',
    'The picnic you planned is rained out. What do you do instead?',
    'What three things around you right now could you use to make a musical '
    'instrument?',
    '‘If you were a supervillain, what would your name be?',
    'Are there are more good than bad people in the world?',
    "What's your best vacation disaster story?",
    'Have you ever tried to run up a down escalator?',
    "What's the craziest vehicle you've ever seen on a highway?",
    'When did you last play leapfrog, and could you still do it today?',
    '701. Youcan only stockpile one item in preparation for potential home '
    'confinement. What is it?',
    'What things do you do without realizing you did them, or without remembering '
    'you did them?',
    "Which one of your friends or family members is scariest when they're angry?",
    "Other than when you're sick, have you ever spent an entire day in bed? When "
    'was the last time?',
    "What's one thing you've had to unlearn?",
    'If you had to draw your life as a line, what would it look like?',
    'What Starburst flavor is your absolute favorite?',
    'Do you walk your talk?',
    "What's the most ridiculous outfit you've seen paraded on a catwalk?",
    'When was the last time you jumped rope, and can you remember any rhymes?',
    'Instead of a white flag, what should be waved to signify surrender?',
    '712. Which appliance in your home is the noisiest when in use?',
    'if you could have afternoon tea with a world leader, who would it be?',
    'What song or piece of music would you be glad never to hear again?',
    'Did you play a cootie game in school, and who did you think had cooties?',
    'What was the last thing you ate that made you extremely thirsty?',
    'Will you ever be happier than you are right now?',
    'How many email addresses do you have, and which is your favorite?',
    "What should the punishment be for people who don't return supermarket carts "
    'properly?',
    'If your nose had to be a fruit, what fruit would you want it to be?',
    'Have you ever tried to sneeze with your eyes open?',
    "Do you have an outdated tech item that you don't want to upgrade? What is "
    'it?',
    'What pajamas did you love the most when you were younger?',
    'Have you ever been so desperate to pee that you thought your bladder might '
    'burst?',
    "What's the deepest underground you've been?",
    "You've created a new search engine: what will you call it?",
    'What pair of shoes have you loved the most in your life so far?',
    'How cold is too cold?',
    'What new language would you like to be fluent in, and why?',
    'Instead of piggy in the middle (or monkey in the middle), what might be in '
    'the middle in a parallel universe?',
    "What's your best travel sickness story?",
    "Do you notice other people's spelling and grammar errors more than your own?",
    'What culture in another country would you find it most difficult to adopt?',
    'Who do you know who could be described as the "salt of the earth"?',
    "Have you ever trimmed a friend's hair? Would you, if they asked?",
    'If you had to exchange ears with an animal, which one would you choose?',
    '—\\What mnemonic has helped you most?',
    'Granny? Grandma? What names do you give your grandparents?',
    'What makes the perfect topping for frozen yogurt?',
    '‘If you were a three-course meal, what dishes would you be?',
    'What three things could go missing from your home and you might never '
    'notice?',
    'Have you ever done a bad thing that turned out to be a good thing? What was '
    'it?',
    'Should fossil fuels be banned?',
    'What magic trick would you most like to be able to perform?',
    'Are you the most competitive person you know, and if not, who is?',
    "Where is the weirdest place you've found a missing TV remote control?",
    'What have you done after being double dared to do it?',
    'Will there ever be a world without hunger?',
    "What's the craziest thing you've seen someone balance on their head?",
    '‘If your only weapon in a zombie apocalypse is whatever you can reach right '
    'now, would you survive?',
    'What food should be made available as a spread?',
    'When was the last time you jumped into a pile of raked leaves?',
    'What pattern would make the funniest crop circle when viewed from the air?',
    'Have you ever felt addicted to playing a game? Which one?',
    'What film from the last year should get the Golden Raspberry Award (for '
    'worst film)?',
    'Did you or do you still have a CD collection? What was the last CD you '
    'bought?',
    "What's the worst case of medical malpractice you've heard of?",
    'If you could have any style of designer sunglasses, what would you choose?',
    "If it didn't rain cats and dogs, what should it rain?",
    "Have you ever pretended to understand something that you really didn't?",
    'What was it?',
    'What accessories are needed to make a perfect snowman?',
    'There are three crocodiles between you and a $1 million dollar prize. What '
    'do you do?',
    "What's the most random thing you've ever found in one of your pockets?",
    'Which one of your friends or family members would be the best at belly '
    'dancing?',
    'Do you believe in Bigfoot?',
    'What was the last thing you beat yourself up about?',
    'If you had to fly south for winter, where would you go?',
    "What's your best tip for dealing with stinky sneakers?",
    'Other than your birthday, what day of the year is your favorite, and why?',
    'What would you like your last words to be?',
    'Instead of a zillion or gazillion, wnat name can you invent for a huge '
    'number?',
    "What's the most profound thing anyone has ever said to you?",
    "You've created a new mocktail. What's in it and what have you called it?",
    "What's the craziest thing you've thrown across a room in a temper?",
    'Will the world ever know who Banksy is?',
    "What's a good example of a product creating a solution and then looking for "
    'the problem?',
    'If your pants really did catch fire when you lie, would your butt have been '
    'scorched today?',
    'Have you ever felt like you wanted to swing from the chandeliers? Why?',
    'When did you last ride a bike?',
    'If it wasn\'t called a “Hershey\'s Kiss," what name would you give it?',
    'Which bit of astronaut training would you do best in?',
    'If you had to give a twenty-minute presentation tomorrow, what would you '
    'talk about?',
    'What YouTuber do you watch most?',
    'Ona scale of one to ten, with ten being the weirdest, how weird would you '
    'say you are?',
    "Boing, buzz, splash...What's your favorite onomatopoeic word?",
    'What would your cowboy name be?',
    'When was the last time you joined a conga line and where?',
    'If you could have anything delivered to you right now, what would it be?',
    'You discover an unknown species of plant. What does it look like and what '
    'will you name it?',
    'What would you say is pure bliss?',
    'Which one of your friends would be most likely to win a plate-spinning '
    'contest?',
    'What three things do adults have that children want to have?',
    'Instead of the well-known “bong,"what sound would be a fun chime for Big '
    'Ben?',
    'If you were a Transformer, what vehicle would you be when you transformed?',
    "What's a healthy way to let off steam and vent frustration?",
    'How many emotions can you convey using facial expressions and gestures '
    'alone?',
    'What current trend do you just not get?',
    'The record for holding the plank position is over eight hours. How long can '
    'you hold it?',
    'What period of history would you like to visit for a day?',
    "If it's your job to hire and fire, how do you fire someone who is also a "
    'friend?',
    "What's your best tip for dealing with a cramp?",
    'Have you ever tripped over your own shoelaces? What happened next?',
    "What's the best voicemail message you've heard?",
    'Do you have any compulsive behaviors?',
    'Will the internet break one day? What will cause it?',
    'If you could have just one piece of home exercise equipment, what would it '
    'be?',
    'Have you ever put anyone on a pedestal? If so, who and are they still there?',
    'If Italy is boot-shaped, what shape can be used to describe your country?',
    "What's the worst diet you've ever gone on?",
    'Have you ever had braces and what did you do to celebrate on the day they '
    'were removed?',
    'What makes the perfect topping for Shredded Wheat?',
    'If your pets (past and present) had to give you a reference for a job, would '
    'you get the position?',
    'What was the last thing you bought for a secret Santa gift?',
    'Have you ever twerked?',
    "What's the craziest thing you can imagine discovering at the center of the "
    'Earth?',
    'Will the world become free of single-use plastics in your lifetime?',
    "What's the craziest thing you've balanced on to help you reach something "
    'high?',
    '“Death by chocolate" is a popular dessert. What other foods should carry a '
    '“danger of death" warning?',
    "Where's the most embarrassing place your stomach has growled?",
    'Is "having a blonde moment" an offensive expression? Why?',
    "What's the funniest place name you've ever seen?",
    'When was the last time you heard birds singing and where were you?',
    "You've created a new carpet shampoo. What does it smell of and what do you "
    'name it?',
    "What's the best word you've ever made in a game of Scrabble?",
    'Who do you know who has mastered the art of eating all they can at an all- '
    'you-can-eat buffet?',
    "What's the most painful thing you've ever stepped on without shoes?",
    'How common is common sense?',
    'What current world news event would you find most difficult to explain to a '
    'seven-year-old child?',
    'If James Bond didn\'t drink martinis, "shaken not stirred,” what drink would '
    'be the most hilarious alternative?',
    'Which one of your friends would you choose to run a three-legged race with?',
    'Have you ever unintentionally said something out loud? What was it?',
    'What\'s the best "going to the bathroom" expression you\'ve heard used?',
    "You're sitting next to a crying baby ona plane and there's four hours left "
    'to go. What do you do?',
    'Do you believe that what goes around comes around?',
    "What's your best team-training or buddy-bonding workshop story?",
    'If you were a tree, how tall would you want to be?',
    'Our galaxy is the Milky Way. What name would you give to a newly discovered '
    'galaxy?',
    'If you could have one professional home improvement made in your home, what '
    'would it be?',
    'Have you ever been on a pilgrimage? Would you like to, and where would you '
    'go?',
    'Will science eventually allow humans to live forever?',
    "Can you beatbox? If not, what's your best effort?",
    'What three things do you associate with Scotland?',
    'Should high-profile sports players quit social media to escape racial abuse?',
    'If your skin had to change to a bright color, what color would you like it '
    'to be?',
    "What's the most miraculous escape story you've ever heard?",
    'When did you last visit a public library and did you take out a book?',
    'Is it ever okay to steal? Under what circumstances?',
    'If Jurassic Park was a real place with actual dinosaurs, would you visit it?',
    "What's the meanest (not deadly) act of revenge you've ever heard of?",
    "Have you ever felt like you're being watched? When?",
    'If you had to get your own "magnificent seven" together, who would be in '
    'your posse?',
    "What's the craziest car insurance claim story you've heard?",
    'Will online shopping see the end of brick-and-mortar shops?',
    'Do you share a birthday with anyone famous?',
    'What actor who tried a singing career made the biggest mistake?',
    'Is it fair to expel students from school?',
    "What's the preferred system you use to keep track of appointments and "
    'important events?',
    'When was the last time you had to swallow your pride?',
    "What's the scariest experience you've had or witnessed?",
    'Have you ever put something away in a safe place and then forgotten where '
    'you put it?',
    "What's the most creative and heroic way you can imagine dying?",
    "If laughter is the best medicine, what's second best?",
    "What's your favorite milkshake flavor?",
    'Would you ever consider participating in a paid clinical trial? Why? If so, '
    'what would be your minimum compensation amount?',
    "What's the craziest autocorrected message you've sent?",
    'Which body part would you miss the least if it dropped off?',
    'Do you have or have you ever had a lucky charm? What is/was it?',
    'What was the last thing you bought that served no real purpose, but you '
    'bought just because you liked it?',
    'Have you ever been pooped on by a bird or any other animal?',
    'What are your top three most frequently used websites for online shopping?',
    'Which one of your friends would you not trust as your house sitter or pet '
    'sitter, and why?',
    "What's the most hurtful thing someone has ever said to you?",
    'You combine your three favorite candy bars into a new product. What will you '
    'call it?',
    'What do you absolutely refuse to believe?',
    'Did you like any of the books you had to read for school?',
    'What person alive today is least likely to ever become a US President?',
    'Have you ever felt misunderstood? When and why?',
    "What's your best story of someone swallowing something they shouldn't have?",
    "If Little Red Riding Hood didn't have a red cloak, what color would it be?",
    "What's the classiest garden ornament you've ever seen?",
    'Do you have recipe books in your kitchen? If so, which one do you use most '
    'often?',
    "You've created a cologne. What's its name?",
    "What's the most spontaneous thing you've ever done?",
    'The skin on your elbow is called the wenus. What name would you give the '
    'skin on your nose?',
    'What makes us human?',
    'If you could have one question about your future answered, what would you '
    'ask?',
    'Have you ever been properly muddy? When was the last time?',
    "What's the weirdest top five list you've come across?",
    'If you had to go ona raw food diet, what meals would you miss most?',
    'Where in the world would you like to be with your friends to see in the next '
    'New Year?',
    "What's the cleverest restaurant name you've ever seen?",
    'Are humans the most advanced species in the universe?',
    'Is it ever wrong to do the right thing?',
    "On a scale of one to ten, what's the greatest pain you've experienced, and "
    'why?',
    "What's the most useless invention?",
    'When was the last time you had to pull something out of the bag to save the '
    'day?',
    'If your surname had to be a food, what name would you like?',
    'What three things do you consider unforgivable?',
    "Have you ever trimmed someone else's toenails? Would you?",
    "What's the snobbiest thing you've heard someone say?",
    'If you had to have a dental implant in a color other than white, what would '
    'you choose?',
    'What do you buy less of than most people you know?',
    "Will any of the happenings of this week be things you'll remember this time "
    'next year?',
    "What's your best staycation story?",
    'Has anyone ever guessed your age to be way under or over your actual age?',
    "What's the most generous tip you've given for good service?",
    'Which one of your online usernames would make a great name for a band?',
    "What's the most fun science experiment you've ever done at home?",
    'People sometimes get a second chance, but would you give someone a third '
    'chance?',
    'What\'s your best “tumbleweed moment" story?',
    'If you were a vacation destination, which one would you be, and why?',
    'What celebrity home do you think shows the worst taste in décor?',
    'If you could have VIP access to any event, which one would you choose?',
    "What's the tallest building you've been to the top of?",
    'Who do you know who is living life to the full?',
    "What's the most interesting meal you could make with potatoes as the main "
    'ingredient?',
    'Do you believe in ghosts and have you ever seen one?',
    "What's the funniest shower curtain design you've ever seen?",
    'Is it okay for museums, theaters, and art galleries to accept money from '
    'fossil-fuel companies?',
    'Have you ever flown first class? What airline would you choose if you could?',
    "What's the oddest thing you've seen advertised for sale?",
    "You've created a brand-new app. What is it?",
    "What's the most disturbing true crime story you've heard?",
    'How many days of plates have you stacked up before doing the washing up?',
    'What do you consider to be the height of bad manners?',
    "Were you bullied at school, and do you remember the bully's name?",
    "What's the most uncomfortable or awkward thing you've ever had to do out of "
    'politeness?',
    "Is it possible to be happy if you've never experienced sadness?",
    'What would your rapper name be?',
    'When do you find you lack discipline?',
    "What's the most shocking experiment you've heard of that would never be "
    'allowed today?',
    'Have you ever been seasick? If so, when?',
    "What's the most random item you've put in your shopping cart in a grocery "
    'store?',
    'Do you hit the recommended 150 minutes of exercise per week target?',
    "What's the most mind-blowing illusion you've seen performed by a magician?",
    'If you were a wildlife camera operator, what would you hope to capture on '
    'film?',
    "What's the spookiest sound you've ever heard?",
    'Have you ever gone swimming in a river? Where and when?',
    "What's the most inappropriate question someone has ever asked you?",
    'When was the last time you had to do a double take? Why?',
    "What's the most fascinating fact you know about the human body?",
    'Did you wear hand-me-down clothes as a child, and would (or do) you wear '
    'secondhand clothes now?',
    "What's the most bizarre name you've seen for a color of paint?",
    "Who's the most sophisticated person you know?",
    "What's the oddest compliment someone has paid you?",
    "Have you ever discovered you've been calling someone by the wrong name for "
    'months?',
    "What's the longest you've gone without a bath or a shower?",
    'Which celebrities have the best style?',
    "What's the most extreme thing you've ever done?",
    'Do you still listen to the music you listened to ten years ago?',
    'Would you know what to do to help someone bleeding badly after an accident? '
    'Have you ever done it?',
    "What personality quirk do you have that you wish you didn't?",
    'If you could hibernate for the winter, what would you eat first when you '
    'woke up?',
    'What was the last thing you built from a flat pack or kit?',
    'Should horror films no longer be made? Why?',
    'What do you currently pay for that should be free for everyone?',
    'Have you ever used a traditional map instead of a GPS? When was the last '
    'time?',
    "Which one of your relatives are you glad your parents didn't name you after?",
    "What's the grossest ancient healing belief you've heard of?",
    "You don't have enough plates for all your guests. What do you serve food on "
    'instead?',
    "What's your best school-science-experiment-gone-wrong story?",
    'lf you had to have an extra limb, what would you want it to be?',
    'What actual names would be funny for Daddy Bear, Mummy Bear, and Baby Bear '
    'in the story of Goldilocks?',
    'Is it possible to have too much choice? When?',
    'What three things do you need before it feels like the weekend?',
    'Do you feel your age on the inside?',
    "What's the worst case of hoarding you've heard of?",
    'lf meat-free foods had meat-free names, what would be a good name for '
    'vegetarian bacon?',
    'What was the last thing you changed the batteries in?',
    'Have you ever purchased anything from an infomercial? If so, what was it?',
    "What's the funniest brand name you've ever seen?",
    'Is there a board game you now play online instead of on a board?',
    'What makes you cry?',
    'You\'ve been tasked with rebranding “Toot Sweets" from Chitty Chitty Bang '
    'Bang. What name will you go with?',
    "What's the biggest unexpected repair bill you've had to pay?",
    'When was the last time you had to cover your eyes when watching TV, and why?',
    'What do you do differently at home when you have guests?',
    'Do you say "shoot" after saying “rock, paper, scissors"?',
    "What's the most lost you've ever been, and where were you?",
    'If you could host a party in an unusual location, where would it be?',
    "What's your best school field day story?",
    'Have you ever been skinny dipping? When was the last time?',
    'What has been the best "message" you\'ve ever found in a fortune cookie?',
    "Who's the most daring real-life hero you know?",
    'Which one of your friends has the weirdest laugh? How would you describe it?',
    'What music have you listened to most today?',
    'A Labrador crossed with a poodle is a labradoodle. What other breeds would '
    'you cross to make a great name?',
    "What's the best riddle you know?",
    'If you had to have stitches that would leave a visible scar, where would you '
    'prefer it to be?',
    'What movie have you seen with a totally ridiculous plot, but you watched it '
    'anyway?',
    'Pickleball is a mix of badminton, tennis, and table tennis. What other three '
    'sports could combine into a new game?',
    "What's been the biggest waste of time in your life?",
    'Have you ever used the Forrest Gump line "Life is like a box of chocolates" '
    'in real life?',
    'What made-up word describes the sound of cheese melting?',
    'There are 118 known elements. What would you call the 119th if you '
    'discovered it?',
    'What would you like to be able to make disappear with just a dab of magic '
    'cream?',
    "What's something exciting that's happened to you this year?",
    'What food outlet would you most like to be receive free food for life from?',
    'Where have you gone that felt like you were "boldly going where no man had '
    'been before"?',
    'What would be the worst food to use as a sandwich filling?',
    'Is it ever okay to take the law into your own hands?',
    'What happens when an unstoppable force hits an immovable object?',
    'Would you like snakes more if they had fur?',
    'What would be an unlikely line to hear in a Star Wars movie?',
    'How many cities can you name beginning with B?',
    "What do you do if a cashier gives you more change than you're due?",
    'If you had to hide 101 dalmatians in your home, where would you put them?',
    'What would be a funny alternative name for Harry Potter?',
    'Have you ever regifted something? What was it?',
    'What will your hobbies be when you retire?',
    'Is someone who hates haters a hater themselves?',
    'What movie explosion is the most awesome?',
    'Who do you know who thinks they are smarter than they actually are?',
    "What was the last gift you bought for someone's birthday?",
    'When have you had too many options?',
    'What image could you use to convey your mood right now?',
    'At what point in your life was your hair at its longest?',
    "What telltale signs appear in your behavior when you're feeling stressed?",
    'You receive a call from an unknown number, do you answer it?',
    'What do you do if the person opposite you at a dinner party is lip-smacking?',
    'If you had to hide a life-size cardboard cutout of The Rock in your home, '
    'where would you put it?',
    'What sounds set your teeth on edge?',
    'When was the last time you had hiccups and how did you cure them?',
    'What playing piece do you always want to be in a game of Monopoly?',
    "Have you ever walked a mile in someone else's shoes?",
    'What was the last thing you changed your mind about at the last minute?',
    "You've been tasked with marketing the unhealthiest food you know as a "
    'healthy option. How do you do it?',
    'What nursery rhyme can you remember all the words to?',
    'Do you hold grudges, and are you holding any now?',
    "What's your best public changing room or locker room story?",
    'If you could hypnotize a family member, what would you get them to do?',
    'What pet name or term of endearment do you hate being called?',
    'Have you ever been talked into doing something you didn’t want to do? What '
    'was it?',
    'What three things should never be joked about?',
    'Is there a canned fruit you like better than the fresh variety?',
    'What guitar riff is the greatest ever?',
    'How many single-use items do you use in an average week?',
    'What\'s the best "dad joke" you know?',
    'Which celebrity chef cooks the type of meals that represent food hell for '
    'you?',
    'What new skill could be learned and mastered within one month?',
    'lf Middle Earth was real, where do you think it would be?',
    'What do you do if someone you meet at a social event is talking bull but '
    'everyone else is sucked in?',
    "Guinea pigs aren't pigs or from Guinea, so what should they be called?",
    'What food would make the top of your comfort food list?',
    'Have you ever walked barefoot outdoors? When and where was the last time?',
    "What's the most expensive meal you've ever eaten and where?",
    "Who's the most artsy-fartsy person you know?",
    'What makes you paranoid?',
    'How many slices of toast could you eat in one sitting? Have you done it?',
    'What facial hair style is your favorite?',
    'Did you catch chickenpox as a kid? If so, how did your parents stop you from '
    'scratching?',
    'What pet did you want most when you were a child but could never have?',
    'If money no longer existed, what would you like to be paid with?',
    "What's the last thing you felt you knew for sure?",
    'Have you ever referred to anyone as Mr. or Ms. Fancy-Pants? What were they '
    'wearing?',
    "What's the most disgusting sound you've ever heard?",
    'Which one of your friends do you wish had a mute button?',
    'If you could instantly be a master of a martial art, which one would you '
    'choose?',
    "What's your best people-watching-at-the-airport story?",
    'You find a spider on your wall at home. What do you do?',
    'What food that you eat have you never seen in its natural, unprocessed '
    'state?',
    'How many clocks do you have in your home and do they all keep the correct '
    'time?',
    'What souvenir would you most like to bring back from another country?',
    'If you had to match your personality to a breed of dog, which breed would '
    'you be?',
    'What added scent would make an unusual bar of soap?',
    "What's the weirdest thing you've seen used to tie up someone's hair?",
    'Is there a conspiracy theory you believe in?',
    "What's the best age to have children?",
    "Would you say you're an artistic person? Why?",
    "What's the most creative use you can come up with for an empty ice cream "
    'carton?',
    'Prince William and Kate are coming to your home for tea. What will you offer '
    'them to eat?',
    'What global issue will technology solve within the next five years?',
    'Do you keep a journal, and if so, how often do you write in it?',
    "What's the funniest family name you've ever come across?",
    'When was the last time you had butterflies in your stomach?',
    'What have you done recently that made you feel you were turning into your '
    'mom or dad?',
    'Should a person be innocent until proven guilty or guilty until proven '
    'innocent?',
    "What's the best shadow puppet you can make with your hands?",
    "Who's the most outrageous performer you've seen live on stage?",
    "What's your favorite food to barbecue or grill?",
    'If you had to make clothes out of your curtains, what room would you take '
    'them from?',
    'What was the last thing you cooked from scratch?',
    "You've been offered $100,000 to do a ski jump. Would you do it?",
    "What's the best basketball trick shot you've ever seen played?",
    'Which one of your friends can do the best evil laugh?',
    "What's the best email address you've ever seen?",
    'Have you ever gone singing and dancing in the rain?',
    'What land animal would be most awesome if it could swim underwater?',
    'What would your WWE (World Wrestling Entertainment) name be?',
    'lf you were an assassin, who would be at the top of your hit list?',
    'Do you think robots will replace teachers in schools?',
    'What three things do you value most in a friend?',
    'What do you do if you accidentally swallow a fly?',
    'Have you ever walked out of a movie theater before the end of the movie?',
    'Why?',
    "What would you have done to get yourself onto a lifeboat if you'd been on "
    'the Titanic?',
    "Is there a food from another country that's impossible to get in your "
    'country?',
    'What motto would you say you live by?',
    'Where have you been that felt like the middle of nowhere?',
    'Is all fair in love and war? Why or why not?',
    "What's your best pancake tossing story?",
    'How many songs can you think of that have numbers in the title or lyrics?',
    "What's the most creative thing you've written with when you couldn't find a "
    'pen?',
    'Which movie would you like to see retold from a different point of view?',
    "What's the most amazing thing you've seen a trained animal do?",
    'If you had to make one part of your body bigger, what would it be?',
    'What would happen if a vampire bit a zombie?',
    'Have you ever flown a kite? If so, when was the last time?',
    "What's the best car windshield sunshade you've seen?",
    'Do you believe in love at first sight? Has it happened to you?',
    "What's the lowest you'll let your phone battery go before you charge it?",
    'When in your life has there been no going back?',
    'What should we use to measure success instead of fame and fortune?',
    'If you could invent a time-saving device, what would it be for?',
    "You're driving on the road and the car behind is intentionally tailgating "
    'you. What do you do?',
    'Would you risk losing a $500,000 prize if you were 75 percent sure you could '
    'win $1,000,000?',
    'What name is least likely to ever be given to a royal baby?',
    'There are five of you and only one slice of pizza left. What do you do?',
    'What petty annoyance has impacted your day today?',
    "Have you ever received a Valentine's card from a mystery admirer who "
    'remained a mystery?',
    'What would be a great name for a racing greyhound?',
    'Which celebrity do you wish had never been born?',
    'What world event in your lifetime will be discussed in history classes in a '
    'hundred years’ time?',
    'Who do you owe most to?',
    'What one rule should never, ever be broken?',
    'If you had to move to a new city, how would you make new friends?',
    'What might the three little pigs have made their houses out of in a parallel '
    'universe?',
    'When was the last time you had a snowball fight and who with?',
    'What would your signature bake be on The Great American Baking Show (Great '
    'British Bake Off)?',
    'Do you own a watch or piece of jewelry that used to belong to a relative?',
    "What's the weirdest thing you've slept on or in?",
    'Have you ever wished on a star and did your wish come true?',
    'What song would you say is your anthem?',
    'An extra month is added to the calendar. What will it be called?',
    'What three things that you have now would you give up to get the one thing '
    'you really want?',
    'How many steps do you take in a day? Do you aim for ten thousand?',
    'What team name would be hilariously ridiculous if cheerleaders had to spell '
    'it out?',
    'Who would you most like to shadow for the day to learn how they handle life?',
    'What was the last competitive thing you did?',
    'If money were no object, where would you choose to eat tonight?',
    'What makes you sentimental?',
    'Do you know any words that mean something very different in another country?',
    "What's the best comeback you've heard when someone's height has been "
    'ridiculed?',
    'Which one of your friends best fits the description of “loud and proud"?',
    'If you were an author, what pen name would you use?',
    'What will cause the extinction of humanity?',
    "You've been given the lead role in a biopic. Who are you portraying?",
    "What's your best hot tub story?",
    "If New York City cabs weren't yellow, what color should they be?",
    'What word is fun to say?',
    "Have you ever forgotten a family member's birthday?",
    'What would be a cool rival company name for Amazon?',
    'Does being an only child mean you miss out on life?',
    'What word could you invent to describe one of your persistent habits?',
    'If you could live in a video game world for a day, which would you choose?',
    'What games did you play in your childhood that kids today have never heard '
    'of?',
    'Have you ever wished you could be in two places at once? When, and where did '
    'you want to be?',
    "What do you do if you can't sleep?",
    "You've been granted access for a private tour of any company or facility in "
    'the world. What do you choose and why?',
    'Queen Victoria did it. Have you ever dunked a biscuit in a cup of tea?',
    'What was the last DIY project you did?',
    'How did you celebrate your last birthday?',
    "What's the best monument or landmark you've seen lit up at night?",
    'When was the last time you had a nosebleed? Where were you?',
    'What would be an appropriate punishment for people who eat food from your '
    'plate?',
    'If no water was available, what would be your next choice to quench your '
    'thirst?',
    "What was the last thing you couldn't help bragging about?",
    'You get asked to design a new Lego set. What would it be?',
    'What superpower would you least like to have, and why?',
    'Where do you think the lost city of Atlantis will be found?',
    'What would paradise look like for you?',
    'Can you come up with a sportswear brand tagline that beats “Just do it!"?',
    'What five things would you put in a time capsule to be dug up in twenty-five '
    'years?',
    'If you had to power your home by pedaling a bike, what would you do '
    'differently?',
    'What would you do if you were being charged at by an angry elephant?',
    'Have you ever been the last to know something? What was it?',
    "What's the loudest thing you've ever heard?",
    "You've been summoned to jury duty and it’s for a high-profile case. Do you "
    'serve or try and get excused?',
    "What's the last purchase or donation you made to a thrift store?",
    'Which one of your friends best fits the description of an “ideas machine"?',
    "It's mid-afternoon and you want a snack. What's your preferred snack food?",
    'How many things do you carry in your pockets, and what are they?',
    'What additional feature will all future cars have?',
    'Do you feel strongly enough about something to go on a protest march?',
    'What is it?',
    'What, if anything, makes you feel most patriotic?',
    "Have you ever found it funny when you've hit your funny bone?",
    "What's the best food that comes on a stick?",
    'Would you thumb a ride if your car had broken down and you had no phone?',
    "What's the longest time you've been kept on hold on the phone?",
    'How many things do you leave plugged in twenty-four hours a day?',
    'What do you do if you see someone walk out of a public toilet with paper '
    'stuck on their shoe?',
    'Should jousting be an Olympic sport?',
    "What's your best home-remedy-gone-wrong story?",
    'Is there a food or drink item that your hometown is famed for?',
    "What's something that's now lost and will never be found?",
    "When it's your ninetieth birthday, which family members will you have around "
    'you to celebrate?',
    'Who would you most like to have a signed photo of?',
    'What hurricane or storm name should be added to the list?',
    'If you had to rename Smurfs, what name would you go for?',
    'What song lyrics have you misheard?',
    'Did you leave a snack for Santa and his reindeer when you were little? What '
    'was it?',
    "What's the best prank pulled by identical twins that you've heard of?",
    'If you were an Olympic swimmer, what stroke would be your strongest?',
    'What three things would you change about your job if you could?',
    'When was the last time you gave someone flowers?',
    'What might Yankee Doodle have stuck in his cap in a parallel universe?',
    'Have you ever gone through a day believing that the events of the previous '
    "night's dream happened for real?",
    'What phrase would you like to add to candy hearts?',
    "You've been buried alive in an avalanche. What do you do?",
    'Which one of the seven dwarfs would you be?',
    "What's the best personalized license plate you've seen?",
    'Do you know anyone guilty of using computerese or tech talk unnecessarily?',
    'What one experience would you like to experience again for the first time?',
    "Has anyone ever told you something you wish they hadn't? What was it?",
    "What do you do if you've forgotten someone's name and you have to introduce "
    'them to someone else?',
    "Have you heard of water tasters or odor prospectors? What's the weirdest "
    "real job you've heard of?",
    'What was the last thing you deleted by accident?',
    'lf you had to replace your right foot with the foot of an animal, what '
    'animal would you choose?',
    'What once-in-a-lifetime experience would you like to be able to repeat?',
    'Who do you think should be crowned the king of pop?',
    'What new emoji would you like to create, and when would you use it?',
    'There are no guarantees in life, but if there were, what one thing would you '
    'like to be guaranteed?',
    'What might Hogwarts be a school of in a parallel universe?',
    'Do you believe in fate? Why?',
    "What do you do to escape from someone who won't stop talking?",
    'If you could make a warning sound like a rattlesnake, which part of your '
    'body would make it, and what sound would it make?',
    "What's your best haircut horror story?",
    'A breakdancing magician? What skill combo would be highly entertaining?',
    'What movie have you watched the most and how many times have you watched it?',
    'Have you ever cried at a TV commercial?',
    'What was the last thing you did that made you sweat?',
    "If music didn't exist, how different would your life be?",
    'What message would you like to put on the inside of a Dove Chocolate Promise '
    'wrapper?',
    'Ring camera? What everyday item could you cunningly disguise to create a '
    'James Bond weapon?',
    'What hand signal or gesture is the most universally known and means the same '
    'everywhere?',
    'Would you stroke a cockroach?',
    'What was the last event or appointment you canceled?',
    "Is there a seat in your house that's reserved for only one person?",
    'What have you been reminded of lately that you would really rather forget?',
    'Which celebrity would you most like to be stuck in an elevator with?',
    "What's the longest bridge you've gone across and where was it?",
    'Should it be mandatory for people earning a salary above $200,000 to '
    'contribute to charity? Why?',
    "What's the longest you've gone without speaking to someone close to you?",
    'If you had to run from danger, how far would you get before collapsing?',
    'What Guinness World Record would you most like to hold?',
    'Is happiness a choice?',
    'When was the last time you gave or received a handmade gift? What was it?',
    'What might The Lion, the Witch and the Wardrobe be called in a parallel '
    'universe?',
    'How many things do you need a physical key for, and which key would be the '
    'toughest to replace?',
    "What's the weirdest thing you've seen strapped on the roof of a car?",
    'How many children are too many children in one family?',
    'What flavor of jelly bean should be introduced?',
    'If music played every time you sneezed, what music would you like it to be?',
    'What makes you smile every time you see it?',
    'Do you agree that live music always sounds better at an outdoor venue?',
    'What do you do to wake yourself up in the morning?',
    'Have you ever gone to the cinema on your own? Would you?',
    "You're gifted one piece of jewelry with an unlimited budget; what item do "
    'you choose?',
    'Who would you like to challenge to a water pistol duel?',
    'What one file on your computer is the most important one?',
    "Curiosity killed the cat. What's the worst trouble curiosity got you into?",
    'What has been your favorite Google doodle?',
    'If you were arrested by the police, what would it be for?',
    "You've been asked to write an original verse for a greetings card. What "
    'would you write?',
    'What slang word from a generation ago should make a comeback?',
    'If you could make a wish that would come true for someone else, what would '
    'it be?',
    'What three things would you never buy without first reading reviews?',
    'What make was your first cell phone?',
    'You get the chance to visit the NASA International Space Station, but you '
    'need to stay for six months. Would you go?',
    'When was the last time you stood up for someone?',
    'lf Nike had to rebrand, what would a good name be?',
    "What's your best gym or exercise class story?",
    "Have you ever found out something you weren't supposed to know by accident? "
    'What was it?',
    'Which device do you primarily use to take photos?',
    'Who would miss you most if you vanished right now?',
    'What movie always makes you laugh, no matter how many times you see it?',
    'If you had to spend $1,000 within the next hour, what would you buy?',
    'What style of jeans do you wear most, and why?',
    'Where and under what circumstances would you least like to audibly break '
    'wind?',
    'If you could make it against the law to do something for one day, what would '
    'it be?',
    'What was the last thing you did that gave you an adrenaline rush?',
    'Had Harry Houdini not died, what would his next escape have been?',
    'What never ends well?',
    'When people mispronounce your name, what do they call you?',
    'What was the last hashtag you created?',
    "You've been asked to name three baby penguins at the zoo. What names will "
    'you give them?',
    'If not "who\'s the daddy?” what do you say when you win something?',
    'What age do you think people should retire at?',
    'ls there a food you only eat in winter, never summer?',
    'What would be a fabulous new aroma for a scented candle?',
    'If your feet increased a size every time you thought about food today, what '
    'size shoe would you be wearing now?',
    'When was the last time you found yourself speechless and why?',
    'What physical attribute is most striking in a beautiful person?',
    'Have you ever won an argument and then discovered you were wrong? What was '
    'the argument about?',
    'What would be an appropriate punishment for people who hog the middle lane '
    'on freeways?',
    'Do you know anyone who can wiggle their ears?',
    'What non-toxic thing will you absolutely not touch with your bare hands?',
    "Have you ever found something you'd forgotten about in a coat pocket?",
    'What was it?',
    "What's the last thing you recommended to someone?",
    'Which one of the Mr. Men or Little Miss characters is most like you?',
    'If you had to stick to the same meal plan every week, what would you eat '
    'every Wednesday?',
    'What would make a fun alternative to standard chess pieces?',
    'Would you walk over hot coals if given the opportunity?',
    'What should there be a new encyclopedia of?',
    'How many times did you get detention in school? For what reasons?',
    'What song do you think is the best to help you keep up the rhythm when doing '
    'CPR?',
    'Should loot boxes in video games be banned for children?',
    "What's your best fancy restaurant story?",
    "Is there a food you'll never, ever try?",
    'What stories have you heard of things caught on “nanny cams"?',
    'Allowing for inflation, what do you think it would it cost to rebuild the '
    'Six Million Dollar Man today?',
    'What thought enters your mind when you see a single shoe lying on the side '
    'of the road?',
    'If you were asked to write your life story for publication, would you hire a '
    'ghostwriter?',
    "As you're walking, you notice a lady sitting on a bench crying. What do you "
    'do?',
    'What would you do if you saw someone shoplift a can of beans?',
    "Has anyone ever said you're their hero? What had you done?",
    'What do you do when people are talking loudly in a movie theater?',
    'Robert Burns wrote a poem to his haggis. Which food would you write a poem '
    'to?',
    "What's the last thing you touched that was too hot to handle?",
    'Which of your spray-on products has the best smell?',
    'What will be the next thing to be banned?',
    "You've been asked to radically redesign $10 bills. What will your design be?",
    'Which character from the Jungle Book would you most like to hang out with?',
    'Who has the best GPS voice?',
    'What was your lowest performing subject at school? Did you ever fail a '
    'subject?',
    'How many books do you read on average in a year?',
    'What would be a good mask for a bank robber to wear today?',
    "You've been asked to invent a new flavor of ice cream; what would it be?",
    "What's never as good the second time around as it is the first time around?",
    'When was the last time you felt totally confused? Why?',
    'What makes a perfectly cooked steak?',
    'If not a billy goat and a nanny goat, what other names would be fun for male '
    'and female goats?',
    'What would be the worst thing to say at a wedding?',
    'There are tea bags and coffee bags; what else should come in bags?',
    "What's the best good news story you've heard recently?",
    'If you could make one minor upgrade to the human body, what would it be?',
    "What's the weirdest thing you've seen turned into a musical instrument?",
    'Is there a holiday that’s outdated and could use a revamp?',
    "What would you do if you knew you couldn't fail?",
    "You've been asked to name a new beauty salon and spa. What will you name it?",
    "What's been your worst hair or beauty disaster?",
    'Who were you with when you re-enacted the “Bohemian Rhapsody" scene from '
    "Wayne's World?",
    "What's the best home remedy for constipation you've heard of?",
    'Do you believe that a leopard never changes its spots?',
    'What was the last thing you did that made you want to kick yourself?',
    'How different would your life be if cell phones had never been invented?',
    "What's your best dinosaur fact?",
    'Have you ever been sunburned?',
    'What do you do when someone invades your personal space?',
    'lf you had to swap fingers with one of your friends, who would you choose to '
    'swap with?',
    "What's the coolest magic trick you've ever seen?",
    'Would your friends describe you as the man/woman for an emergency?',
    'Could you get through your day if you could only use one arm?',
    "What's the best anti-aging tip you ever heard, and have you tried it?",
    'Is there a long-standing tradition in your family? What is it?',
    "What's the coolest thing you've seen made of recycled materials?",
    'Have you ever had a cold shower, and was it by choice?',
    "What's the first sign of spring each year?",
    'lf you were born on February 29th, on what date would you celebrate your '
    'birthday in non-leap years?',
    'Do professional sports players get paid too much? Which ones in particular?',
    "What's the highest score you've ever achieved on a test?",
    'If not a giant beanstalk, what would your magic beans grow into?',
    "What's the longest amount of time you've spent indoors without going outside "
    'at all?',
    'You get to add one word to the book of life. Which word will it be?',
    "What do you do when you're approached by beggars on the street?",
    'ls there a name for a combined yawn and burp?',
    "What's the longest you've gone without sleep, and why?",
    'How many bones in your body do you know the medical terms for?',
    "What's the most beautiful thing you see every day?",
    "What's the most ridiculous thing you've ever accidentally poked yourself in "
    'the eye with?',
    'When was the last time you felt sand between your toes?',
    'If you could name a new shape, what shape would it be and what would you '
    'call it?',
    'Which one of your friends or family members has the noisiest way of blowing '
    'their nose?',
    'Have you heard of the ice bucket challenge? What new fundraiser would you '
    'devise to raise money for charity?',
    'What would need to happen today for you to be in a better mood than you are '
    'now?',
    'If you were compiling a book of family favorite recipes, what would go in '
    'the dessert section?',
    "What's the most introverted thing you've ever done to avoid other people?",
    'Should marriage be a contract that can be renewed or canceled on an annual '
    'basis?',
    'Which character from the Thomas the Tank Engine stories are you most like?',
    "Who has the coolest tattoos and what's cool about them?",
    "What's the most amazing story an old person has told you?",
    'Have you ever worn socks in bed?',
    'What would be the funniest shape to trim a garden hedge into?',
    'If you had to take part in a field day wheelbarrow race, which part of the '
    'wheelbarrow would you be?',
    "What's the weirdest thing you've heard of a fan asking their idol to sign?",
    "You've been asked to create a new family board game; what three ideas will "
    'you trial?',
    'What were you researching when you last fell into a Wikipedia rabbit hole?',
    'Who was your first kiss with and when was it?',
    'Which of your bad habits would you find hardest to break?',
    'What sport did you enjoy playing most at school?',
    'How many times have you looked in a mirror today?',
    'If you could never have hot food again, what meal would you miss most?',
    "What's the highest above sea level you've ever been and where were you?",
    "When you're getting dressed, do you always put items on in the same order?",
    'What one question will always remain unanswerable?',
    "Hamburgers don't contain ham. What other foods have names that don't seem to "
    'relate to what they are?',
    'Do you identify more with Coke or Pepsi and why?',
    "What's your best babysitting or babysitter story?",
    'Did you ever push something up your nose or in your ear as a child? What was '
    'it?',
    "What do you have that money can't buy?",
    'There can only be one TV channel. Which one should it be?',
    'What plain-colored animal would look coolest with stripes?',
    'Have you ever had a haircut to look like a celebrity?',
    'Which movie is crying out for a sequel?',
    "What's the coolest victory dance you've seen anyone do?",
    'Are there any playground games you played as a kid that have now been '
    'banned?',
    "What's the best prize you've ever won in a competition?",
    'Which of the seven deadly sins are you most guilty of?',
    "You need to convince someone that the world is flat. What's your strongest "
    'proof or evidence?',
    'What three words would you use to describe your personal style?',
    'If you were cremated, where would you want your ashes scattered?',
    "What's the best piece of advice anyone ever gave you?",
    'Which of the outfits you own would be the most ridiculous to wear on an '
    'outdoor activity day?',
    'Who was the popular kid in your school and why were they so popular?',
    "What's been the messiest thing you've accidentally dropped?",
    'How many times would you fail your driving test before giving up?',
    'What famous person would you least like to be paired with as a ballroom '
    'dance partner?',
    'When things go bump in the night, what do you think those things are?',
    "If not a fat lady singing, what else would let you know it's all over?",
    'What was the last thing you did that you instantly regretted doing?',
    'Is there a social media influencer that you admire, and why?',
    "What's the best thing to have on toast?",
    'You go to your locker after a swim and discover your shoes have vanished; '
    'what do you do?',
    "What's the weirdest thing you've heard of people putting on a hot dog?",
    'Have you ever wound anything up by hand or with a key? What was it?',
    "What's the rarest thing in the world?",
    'When was the last time you felt out of your comfort zone and what were you '
    'doing?',
    'What forgotten item would you least like to find in a coat pocket?',
    'How many unfinished projects do you have right now?',
    'What might be different about Snow White and the Seven Dwarfs in a parallel '
    'universe?',
    'Has anything ever made you appear guilty, even though you were innocent?',
    'What was it?',
    "What are the most northerly and southerly points you've visited on a world "
    'map?',
    'For what one thing do you think the legal age could be lowered?',
    'What do you have that you would like better if it was a different color?',
    "You've been asked to coin a catchphrase for Greta Thunberg. What will it be?",
    'What land animal would be the most spectacular if it sprouted wings and '
    'could fly?',
    'If you could never leave your home again, what would you miss most?',
    'What musical instrument creates the saddest sound?',
    'What\'s your best “tried to be really quiet but ended up being really noisy" '
    'story?',
    'How many verses of your national anthem can you sing by heart?',
    'What would you do to get the attention of a room full of noisy children?',
    'Do you (or would you) discipline your children in the same way your parents '
    'disciplined you?',
    'What have you done recently that you hope no one saw you doing?',
    'If not a pail of water, what else might Jack and Jill have gone up the hill '
    'for?',
    "What facial feature do you have that you'd never want to change?",
    "How different would your life be if you didn't have internet access?",
    'What food would you never want to eat on a first date?',
    'When was the last time you felt on top of the world and why?',
    'What would be the most ridiculous substitute for the ponies in the Pony '
    'Express?',
    'lf you could never watch TV again, what show would you miss most?',
    'What new character would make a good addition to the suspects in Clue '
    '(Cluedo)?',
    'Have you ever had a magazine subscription? Which one?',
    'What album do you love every single track on?',
    'Which slang word do you use most?',
    'Can you usually name a song just by hearing the intro?',
    "What's your best “there ain't no such thing as a free lunch” story?",
    'If not a tortoise and a hare, what other two animals would make mismatched '
    'race competitors?',
    "What thing that money can't buy would you most like to have?",
    'If you were given one million dollars to help others, what would you do with '
    'it?',
    'Which chocolate do you always choose from the box if you get first pick?',
    'If you had to walk backward for a day, what bit of your day would be most '
    'awkward?',
    'What would be a hilarious topic for prolific songwriter Ed Sheeran to write '
    'a song about?',
    'When you were ten, what age did you think was really old?',
    'Have you ever rescued an animal? What was it?',
    'What time of day do you like best?',
    'You need to declutter your living space. Which three things could you part '
    'with right now?',
    'What song or tune has been stuck in your head recently?',
    "Do you agree that there's always someone worse off than yourself?",
    'What famous quote would make the best advertising slogan for a shoe company?',
    'Have you ever been the only person in the room not to get the joke? What was '
    'the joke?',
    'What was the last thing you did to treat yourself?',
    'How many times do you boil a kettle on an average day?',
    'What non-lethal and non-physically violent method of torture would be most '
    'effective?',
    'Is there a song you used to really like until you discovered what the '
    'message in the lyrics really was?',
    'What famous person (living or dead) would you like to have as a mentor?',
    'Who have you hated for the longest time, and will you ever not hate them?',
    'At what age are you too old to street dance?',
    'What playground game would make a great Olympic sport?',
    'Is there a tall tale your grandparents told you that you were never quite '
    'sure whether to believe?',
    "What music do you find most irritating when you're put on hold?",
    'Should mass balloon releases be banned?',
    'What GIF have you shared with others most recently?',
    'Have you heard of Stinking Bishop or Ticklemore cheeses? What would be a '
    'great new cheese name?',
    "What do you have today that you didn't have this time last year?",
    'When was the first time you ate with chopsticks?',
    'What myth would you most like to be able to bust?',
    'Do you know anyone who has let a tiny amount of power go to their head?',
    'What\'s your best “priceless item found in dumpster" story?',
    'You\'re writing a pop song. What lyrics do you rhyme with "She had jet-black '
    'hair ..."?',
    'What punishment should people who drop litter be given?',
    'If you could no longer chew, what food would you miss eating most?',
    'Which one of your friends has the worst table manners?',
    'What were the most common names for babies in the year you were born?',
    'Have you ever wondered what would happen if every flushing toilet on Earth '
    'was flushed at once?',
    'What store would you most like to have a $500 gift card for?',
    'Who was the last person you went to the cinema with and what movie did you '
    'see?',
    'What technology of today will become obsolete first?',
    "There's a cow-tree in the Amazon. What's the weirdest plant you've heard of?",
    'What would be a handy addition to have built in to a wristwatch?',
    'If you were going to be stuck in an elevator for several hours, what food '
    'would you want brought to you?',
    'What three things make a person likeable?',
    "You have $100 to improve someone else's life today. What do you do with it?",
    'What skill do you have that would keep you alive in a zombie apocalypse?',
    'Did you ever do the mannequin challenge? What was your pose?',
    'What would be the most shocking thing to discover on Mars?',
    "When was the last time you felt like you'd made a difference?",
    'What non-banned item would be a scary thing to take on a plane?',
    "It's dark and stormy outside. Would you answer an unexpected knock at your "
    'door?',
    'What names did you give to your two favorite toys as a child?',
    'Have you ever cried tears of happiness? When was the last time?',
    'What was the last thing you downloaded?',
    'If you had to swap teeth with an animal for the day, what one would you '
    'choose?',
    "What would you say you've done to make the world a better place?",
    'Do you fear robots taking over the world? Why?',
    "What's the best purchase you ever made at a dollar store?",
    "Have you ever gone to work (or school) wearing yesterday's underpants?",
    'What job do you think is most underrated and why?',
    'How much money is enough money?',
    "What's the craziest thing you've done when you've been sleep deprived?",
    'Is there a taste you can always detect, even if people try to disguise it?',
    'You need to make a gluten-free vegan lunch. What do you make?',
    'Have you heard of triffids or piranha plants? What name would you give a '
    'fictional man-eating plant?',
    'What tiny achievement always feels like a really big achievement to you?',
    'If not as “old as the hills,” what else might things be as old as?',
    'What advice would you give your ten-year-old self?',
    'Has anyone ever said you remind them of someone famous? Who was it?',
    "What's the grossest thing you've ever seen in a jar?",
    'When was the last time you felt like screaming at someone and what had they '
    'done?',
    'What food should people be banned from eating in confined public spaces?',
    'Do you agree that there\'s “no such thing as a stupid question"?',
    'What do you love more than cats love boxes?',
    'Have you ever fried an egg on the hood of a car?',
    "What do bears eat at a teddy-bear's picnic?",
    'Have you ever broken anything in a shop and had to pay for it?',
    'What do you worry about that other people tell you not to worry about?',
    'If you were a dog, would you hold the record for holding the most tennis '
    'balls in your mouth?',
    "What was the subject of the most interesting conversation you've had this "
    'week?',
    'Which movie title becomes the most ridiculous if you tag “versus zombies" '
    'onto the end of it?',
    "Can you solve a Rubik's Cube, and if so, how fast and in how many moves?",
    'What was the last thing someone had to forgive you for?',
    'If you had quadruplets, what would you name them?',
    'What would you say is a stereotypical American food?',
    'Who is the weirdest person that ever sat next to you on a bus, train, or '
    'plane?',
    'What do people quarrel about the most?',
    'ls there a word you always have difficulty spelling correctly? What is it?',
    'What would make the most romantic marriage proposal ever?',
    'Which three famous people (past or present) would you most like to play a '
    'game of Twister with?',
    'What have you grown out of that you thought you never would?',
    'Do you have a sixth sense, and how would you explain it to others?',
    'What was the last thing someone said or did that you were offended by?',
    'What was the last straw for you?',
    'Have you ever seen a solar eclipse?',
    'What would you do if you found a raccoon in your kitchen?',
    'When was the last time you used a sweeping broom, and what were you '
    'sweeping?',
    'What one word could you use to describe your mom?',
    'Do you still use the same social media platforms today that you used a year '
    'ago?',
    'What routine habit or practice in your home might visitors find a little '
    'odd?',
    'Have you ever sent a text message to the wrong person? What happened?',
    'What fictional family would be the worst to have as your real family?',
    'At what point in your life did you feel the greatest peer pressure?',
    'What would you do if you heard a tornado warning?',
    'When was the last time you traveled by train and where were you going?',
    'Starsky and Hutch? Cagney and Lacey? What names would make a cool- sounding '
    'cop duo?',
    'What plants or flowers would you grow in your ideal garden?',
    'How long should the tea bag stay in water to make the perfect cup of tea?',
    'What would you like to see commemorated on a coin?',
    'Do you always sleep in the same position? If so, what is it?',
    "What's the weirdest app you've heard of?",
    'When was the last time you felt envious of someone?',
    'What would you most like to win a lifetime supply of?',
    'lf you had one extra hour every day, what would you do with it?',
    'Have you ever played a non-lethal version of Russian roulette? What was it?',
    "What do people get overly upset about that they really shouldn't?",
    'lf you were a dish on an expensive restaurant menu, how would you describe '
    'yourself?',
    "What's the worst thing you've had stuck on the sole of your shoe?",
    'When was the last time you said "What was | thinking?” and why?',
    'What would you carry if it all had to be carried in a red-and-white spotted '
    'hanky tied onto a stick?',
    'Do you have a routine way to wash yourself in the shower or bath?',
    "What was the subject of the most impressive ice sculpture you've ever seen?",
    'Is there a word you sometimes have difficulty saying? What is it?',
    'What was the last big decision you had to make?',
    'How long does it take you to get ready for work (school) each morning?',
    'Which three foods would you always peel before eating?',
    'What would you do if you found $500 in an envelope left behind on a bus?',
    'Have you ever seen a fake so good you were convinced it was real?',
    'What have you had to wait a long time for but was totally worth it?',
    'You lose your bathing suit while swimming in the sea. What do you do?',
    'What was the last book you read and how would you score it out of ten?',
    'Did you ever have your face painted as a child? What was your favorite face?',
    'What have you felt guilty about recently?',
    'How long have you had the oldest item of clothing you still wear?',
    "What's your favorite long-lost pet reunion story?",
    'If you had no cups or mugs in the house, what would you use for hot drinks?',
    'What would make a good alternative saying for “the black sheep of the '
    'family"?',
    'Have you ever been caught picking your nose?',
    'What faux animal pelt would make the most ridiculous rug?',
    'Can you talk in rhyme? At what point does it stop being funny?',
    'What would the blurb on the back cover of your memoirs say?',
    'If there were six Spice Girls, what spice name would you give the sixth one?',
    "What's your favorite meat-free meal?",
    'Have you ever parked in a disabled parking space without a permit?',
    'What disease would you least like to be told you had?',
    'If you had identical twins, would you dress them in identical outfits?',
    'What would you add to existing roller coasters to make the best ever roller '
    'coaster?',
    'Steak in a toaster? Who is the laziest cook you know?',
    'When was the last time you used the stairs instead of the elevator?',
    'Do you always say what you mean and mean what you say?',
    'What was the last random thought you had in the shower?',
    'If you were a circus performer, what would your act be?',
    'Which member of your family is the most clueless about technology?',
    'Have you ever broken a safety rule? What was it?',
    'What would you advise everyone never to wipe their butt with?',
    'Can you imagine a situation in which you might consider cannibalism to stay '
    'alive? What would it be?',
    'What are you not afraid of now that you were afraid of when you were '
    'younger?',
    "What's your favorite topic on YouTube to watch?",
    'Have you ever owned a Sony cassette-based Walkman?',
    'What have you heard recently that shocked you?',
    'If you had cat-like agility, what would you do with it?',
    'What did your parents think was just a phase you were going through, but '
    "you're still into it now?",
    'Does the idea of public speaking scare you? Have you done it?',
    'What rooftop would you most like to sit on to watch the world go by?',
    'When was the last time you vomited?',
    'What would it take for you to have a perfect day?',
    "ABBA is an acronym of the band members' first names. What three friends "
    'could you make a band name with?',
    "What's your favorite Mexican food?",
    'If your body was made of Play-Doh, would you reshape it?',
    "Who is the rudest person you've ever met? How were they rude?",
    'What was the first video game you played?',
    'If you had hair like Rapunzel, how would you style it?',
    'What would make the funniest replacements for an egg and spoon in a race?',
    'Have you ever shrunk anything in the wash? What was it?',
    'When was the last time you felt cheated?',
    'If there were only two kittens left in the litter, would you still take just '
    'one?',
    "What's the weirdest coincidence you've read or heard about?",
    'Do you always read the small print and terms and conditions before clicking '
    '"accept"?',
    'What one word best describes your childhood bedroom?',
    'Did you ever keep tadpoles in a jar as a kid?',
    "What's the weirdest combination of items you've ever put through a grocery "
    'store checkout?',
    "If there's one thing you're a sucker for, what is it?",
    'What was the naughtiest thing you did as a kid?',
    'How long does a perfect boiled egg need to boil for?',
    'What DIY skill would you most like to have?',
    'Someone at your workplace or school is not who they say they are. Who do you '
    'suspect?',
    'What fashionable thing of today will become old-fashioned first?',
    'Have you ever been caught in the rain and completely drenched?',
    'Which three letters on a keyboard do you use most?',
    "Is there an actor that appears in every movie you haven't liked? Who?",
    'What was the first thing you thought about when you woke up this morning?',
    'If you could trade places with a family member or friend for a day, who '
    'would you pick and what would you do?',
    'What would be your perfect personal hangout spot, and where would it be?',
    'If you were a daredevil juggler, what three or more items would you juggle '
    'with in your act?',
    'When was the last time you saw a lightning storm?',
    'What would be your weapon of choice in a zombie apocalypse?',
    "If you're to be known by just one of your character traits, which one would "
    'you like it to be?',
    'Could dinosaurs and humans have coexisted on Earth?',
    'If you had a personal chef to cook your next meal, what would you order?',
    'Which three qualities make someone a good boss?',
    'Have you ever made the same mistake twice? What was it?',
    'What did you spend on the most expensive pair of sneakers you ever bought?',
    'At a guess, how many Pringles could you fit in your mouth at once?',
    'What role would Keanu Reeves play in the movie of your life?',
    'Have you ever boycotted a product because the TV commercial annoyed you?',
    'What fate would you not wish on your worst enemy?',
    'If you had a secret bunker, what would be in it?',
    'When was the last time you walked into a room and forgot why you went in '
    'there?',
    'What would be the worst type of food to store in your pocket for later?',
    "Do you have a possession that you wouldn't let someone borrow? What is it?",
    'What discovery would you like to be famous for making?',
    'You must choose between your two absolute favorite desserts. How do you '
    'choose?',
    'Where would you absolutely not move to, even if you were offered the job of '
    'your dreams there?',
    'What have you learned today?',
    'If you had all the time and Lego bricks in the world, what would you build?',
    'What was the first joke you ever learned?',
    'Have you ever met a “Karen” who was actually called Karen?',
    "What's your favorite music platform?",
    'If you had an accident and had to go to the hospital, who would you want to '
    'go with you?',
    'What would be the most ridiculous car for the Incredible Hulk to drive?',
    "If toothpaste wasn't minty, what flavor should it be?",
    'When was the last time you felt alone in a crowd?',
    'What was the first movie you ever saw in a movie theater?',
    'Have you ever been camping, and where did you go?',
    'What would be the worst choice of song for a first dance at a wedding?',
    'If you had a hot air balloon, what design or message would you print on it?',
    "What's your favorite orange-flavored thing?",
    'Could you perform CPR (cardiopulmonary resuscitation) in an emergency?',
    'Have you ever needed to?',
    'What have you most recently experienced for the first time?',
    "How long (time or miles) was the longest walk you've been on?",
    "What was the most boring event you've ever had to attend?",
    'If you had a personal assistant for a day, what would you have them do?',
    'What would be the worst non-monetary prize you personally could win ona game '
    'show?',
    'Have you ever made a big mistake that no one ever found out about—until now?',
    'What would be the worst smell for a scratch-n-sniff product?',
    "If you're told not to think of pink elephants, what do you think about?",
    'What are you most looking forward to tomorrow?',
    "Is there an emoji you'll never use?",
    'Do you believe in reincarnation? What would you like to return as?',
    'Which member of your family do you talk with the most?',
    'If you had a CB radio, what would your handle be (good buddy)?',
    'Which three websites do you visit most often?',
    'Do you always guess who did it in a whodunnit story?',
    'What have you seen or heard recently to restore your faith in humanity?',
    'If there was a fifth Ninja Turtle, what would their name be?',
    'What was the first horror movie you saw?',
    'If there were no cats on Earth, what would replace cat videos on the '
    'internet?',
    'What would be the downside of being immortal?',
    'Were your schooldays the happiest days of your life? Why?',
    "Is there an item of clothing in your closet that you haven't worn in the "
    'last year?',
    'What would be the most boring pet to have?',
    'Who is the oldest person you know?',
    'What fashion or trend will never become outdated?',
    'Have you ever said, "It\'s not you, it\'s me” to anyone, and how did they '
    'take it?',
    'When was the last time you watched a DVD? What was it?',
    "What would be the most difficult part of your day if you couldn't bend your "
    'knees?',
    'If you had a fairy godmother, what one magic spell would you like her to do '
    'for you?',
    'What did you do when you realized “the cavalry ain\'t coming" to help you?',
    'How hot is too hot?',
    'What did you spend most of your allowance on as a child?',
    "Do you always make your bed in the morning? If not, what's the longest it "
    'has gone unmade?',
    'What was the first alcoholic drink you tried, and how old were you?',
    'You have to provide a spontaneous fun fact about anything. What is it?',
    'What did you do as a child that you absolutely would not do now?',
    'If you were a champion snowboarder, what would your signature trick be?',
    'When was the last time you saw sunrise, and where were you?',
    'What rock song would sound most awesome sung by a barbershop quartet?',
    'Have you ever saved coins in a piggy bank? How much did you save?',
    "What's the weirdest contest you've ever heard of?",
    'Should you fake it until you make it? Have you done that?',
    'What did you last daydream about?',
    'Can you do an underwater handstand? When was the last time?',
    'What would be the best thing about being a monkey for the day?',
    'When was the last time you were in trouble, and why?',
    'Have you ever owned a Tamagotchi?',
    'What was the first curse word you dared to use in front of your parents?',
    "If you're the hero in your life story, who is the main villain?",
    "Do you always follow the same morning routine? What happens if it's "
    'interrupted?',
    'What one thing would you miss most about the area you live in if you had to '
    'move far away?',
    '"Taco cat" is a palindrome (spelled the same backward as forward). What '
    'other palindromes do you know?',
    'War: what is it good for?',
    'What would be the most awesome and ridiculous thing to row across the '
    'Atlantic in?',
    'When was the last time you fell flat on your face?',
    'What famous mystery would you most like to be able to solve?',
    "If you're having trouble getting to sleep, what fun thing might you count "
    'instead of sheep?',
    'You need a shock-and-awe outfit to wear at a red-carpet event. What is it?',
    'What was on the last list you made?',
    'If you found buried treasure at the bottom of your garden, what would you '
    'want it to be?',
    "Why doesn't glue stick to the inside of the tube?",
    'Are you ambidextrous? When do you, or would you, find it most useful?',
    'Which member of the British royal family would you most like to meet?',
    'If you had a bucket list of things NOT to do in life, what would you put on '
    'there?',
    'What would be an appropriate made up collective noun for a group of '
    'teenagers?',
    'Have you ever bought two identical items of clothing and only worn one?',
    'What was it?',
    'What did you buy with your first paycheck or money you earned doing a job?',
    "lf there's life on another planet, what does it look like?",
    "What's your favorite pick at a Pizza Hut salad bar?",
    "Do you have a pen that's also a flashlight? What other gizmo combos do you "
    'have?',
    "What was the most awesome graffiti you've ever seen?",
    'Have you ever been able to do any yo-yo tricks? Which ones?',
    'What have you tried to do that you discovered you were terrible at doing?',
    "Do you strike a pose when someone takes a picture of you? What's that pose?",
    'What one thing will you never give up on?',
    "You're in the shower, the door is locked, and you see a snake slither out of "
    'the toilet. What would you do?',
    'What would be a more creative name for peanut butter?',
    'If you were a celebrity chef, what would your signature dish be?',
    'What extinct animal would you most like to bring back?',
    "How long was the longest flight you've been on and where were you going?",
    'What was the big playground craze when you were a kid? Were you into it?',
    'If you found a secret passage in your home, where would you like it to lead?',
    'Do you always choose the easy option?',
    'What healthy version of a food tastes better than the unhealthy version of '
    'the food?',
    "Wardrobe malfunction! You've popped a button on your pants. What do you use "
    'to hold them up?',
    'When was the last time you woke up with a start in the night? Why?',
    'lf Thomas the Tank Engine was given a twenty-first century revamp, what '
    'modern names might the engines be given?',
    'What was the first card trick you learned how to do?',
    'How long do you wait for a web page to download before you give up and move '
    'on?',
    'What are you most likely to choose to eat from an Indian restaurant menu?',
    'If you found a wedding ring on a sidewalk, what would you do?',
    "What's your favorite pickled food?",
    'Have you ever been a pet sitter for a friend? What animal did you look '
    'after?',
    'What would be a creative name for the pit in the crook of your elbow?',
    '“Raindrops on roses and whiskers on kittens..." What are a few of your '
    'favorite things?',
    "What was on the best bumper sticker you've ever seen?",
    'Have you ever made a snow angel? When was the last time?',
    "What's your favorite rags to riches story?",
    "If you're bilingual, what language does the voice in your head speak?",
    'What would be a great alternative name for Frodo in Lord of the Rings?',
    'When was the last time you wore galoshes (rubber boots)?',
    "You're invited to a teddy bears’ picnic. What teddy will you take?",
    'What expressions used by teenagers today are most confusing for the older '
    'generation?',
    'Do you always stick by the ten-second rule if you drop food on the floor?',
    "What road sign that doesn't exist do you think should exist?",
    'If you found a fly in your soup in a restaurant, would you stay for the next '
    'course?',
    'Who is the noisiest person you know?',
    'What would be a great noise for a toaster to make to let you know your toast '
    'is ready?',
    'Have you ever said, “There must be more to life than this," and what were '
    'you doing at the time?',
    'If you were a caped crusader, what color would your cape be?',
    'What was the last word you looked up in a dictionary?',
    "At what age did you leave your parents' home, or at what age should you "
    'leave home?',
    'What devices have you fixed recently by switching them off and switching '
    'them on again?',
    'Have you ever organized a surprise party for anyone?',
    "If you dinged someone's car in a parking lot, would you leave your contact "
    'details?',
    'What would be a good collective noun for a bunch of five-year-old kids?',
    'When was the last time you wrote a thank-you note, and who was it for?',
    'Have you ever met a celebrity and did they look different in real life?',
    'What was in the weirdest sandwich you ever made?',
    'You have to create a storefront window display for a department store. What '
    'theme will you use?',
    'Which TV commercial (good or bad) is the most memorable for you?',
    'If you fear the dark, what is it you think might be hiding in it?',
    'What herbal remedies do you swear by?',
    'Did you ever have a secret handshake or code that only you and your friends '
    'knew?',
    'What extra button would you like on your most-used remote control?',
    'If there is a parallel universe, what are you doing differently in it?',
    'What would be a good twenty-first-century update for the expression "strong '
    'as an ox"?',
    'When was the last time you spoke without thinking and what did you say?',
    'If there was such a thing as an inconvenience store, what would you be able '
    'to buy there?',
    'Have you ever met anyone from Australia named Bruce or Sheila?',
    'What date from history class sticks in your mind most?',
    'How long can you hold your breath for? How did you find out?',
    "What's the toughest interview question you've ever had to answer?",
    'If you found a bag of money on the street, what would you do?',
    'What would be a good name for baby octopuses?',
    'When was your last eureka or “aha!” moment?',
    "If you didn't have or couldn't get the job you wanted, what would be your "
    'second choice?',
    'What expression might replace "if pigs could fly" in a parallel universe?',
    "Have you ever broken someone's heart? Who and when?",
    'What design makes the best paper airplane?',
    'Can you imitate any animal noises? Which ones?',
    'What one thing will you never get used to?',
    'Have you ever bungee jumped? Where would you do it if given the chance?',
    'What was the last weird coincidence you experienced?',
    'How long was the longest game of Monopoly you ever played?',
    'Which member of the Beatles would you most like to have had lunch with?',
    'When was the last time you experienced pins and needles and where on your '
    'body?',
    "Is there an opportunity you feel you've missed and will never have again?",
    "What did the most ridiculous hat you've ever seen anyone wearing look like?",
    'If there had to be a sound attached to every step you took, what would you '
    'want it to be?',
    'What historical fashion (era or clothing) would you like to bring back?',
    'Should you always act your age, and what does that mean for you?',
    "What's your favorite shape and why?",
    'Do you have a party trick? What is it?',
    'What video game would make a great TV show?',
    'Do you agree that seeing is believing?',
    'What hit song do you know all the dance moves for?',
    'Have you ever bounced on a Hoppity Hop (Space Hopper)? When was the last '
    'time?',
    "What daring thing would you do if you knew you wouldn't die doing it?",
    'When working out, do you prefer silence or sound (music, podcast, TV)? Why?',
    'Are you a perfectionist? If so, when does perfectionism strike most?',
    'What would be a creative name for mashed potatoes?',
    'Have you ever answered the phone and pretended to be someone else?',
    'What type of snake scares you most, and why?',
    "You're in a crowded place. How would you get the attention of a friend "
    'standing twenty feet away?',
    'Which three words would you use to describe your parents?',
    "How long was the longest wait you've ever had in a waiting room?",
    'What everyday thing that lots of people do have you never done?',
    'If there could only be one type of cake in the world, what should it be?',
    'What would be a deal breaker for you in a new job offer?',
    'When was the last time you stared longingly at an item in a shop window, and '
    'what was it?',
    'Do you always eat at the same times every day?',
    'What was in the coolest park you ever visited?',
    'If you were a cat, where would you sleep all day?',
    'What are you most afraid of?',
    'How high would you climb from the ground without wearing a safety harness?',
    "Have you had head lice? What's the weirdest head lice treatment you've heard "
    'of?',
    'What type of pizza crust is your first choice?',
    'If you were a butterfly, wnat colors would you be?',
    'What crazy cat video has made you laugh loudest?',
    'Can you say hello and goodbye in any other languages? Which ones?',
    "What's the weirdest example of taxidermy you've seen or heard of?",
    'If there could be only one color of pen, what should it be, and why?',
    'What daily task would be funniest if you had to do it at sloth speed?',
    'Have you ever lost your voice? How did you communicate?',
    'What type of scenery do you find most beautiful?',
    "Do you always stay within the lines when you're coloring in?",
    'When you meet someone new, what do you notice first?',
    'If you didn’t want to be alone, who would you ask to come over?',
    'What was the last thing you wrote by hand?',
    'Have you ever buried anyone in sand at the beach?',
    '“Purple Rain" was a hit for Prince. What color rain would you like to see?',
    'What do you fear about getting older?',
    'Whois the most unlikely actor to play the next James Bond?',
    "If you're an anime fan, which one do (or did) you watch most?",
    "What's your favorite slang term for money?",
    "Have you ever said you liked something you'd never heard of just to impress "
    'someone? What was it?',
    'What creative thing could you make using empty egg cartons?',
    'What home workout equipment do you have? Do you ever use it?',
    'Should vaccinations be made mandatory? Why?',
    'What was the last thing you wished for when blowing out birthday candles?',
    "If you couldn't eat solid food for a week, what would you miss most?",
    'Which letter of the alphabet would you say is your favorite and why?',
    "When you think of home, what's the first thing that comes to mind?",
    'What world leader (past or present) would make the worst leader for your '
    'country, and why?',
    'Did you ever perform in a school play? What part did you play?',
    "What cool thing has become so popular that it's no longer cool?",
    '|f the world was going to end tomorrow, would you want to know?',
    'What holiday tradition does your family maintain?',
    'Have you ever accidentally worn odd socks or shoes?',
    'What one thing that you forgot to do had the longest-lasting consequences?',
    "You're going to shave your head and rent your scalp out for advertising. "
    'What would you refuse to advertise?',
    'Do you know the actions that go with the "Baby Shark” song?',
    'When was the last time you exercised and what did you do?',
    'You have to choose one reality TV show to appear on. Which do you choose and '
    'why?',
    "What's your favorite song with a day of the week in the title or lyrics?",
    "Is there any type of cake that you couldn't manage to eat two generous "
    'slices of?',
    'Have you ever allowed someone else to take the blame for something you did? '
    'What was it?',
    'What word do you always need to write down to check how to spell it?',
    'Do you believe in miracles? Why?',
    "If you couldn't use the word “awesome,” what word would you use in its "
    'place?',
    'What type of person do you find most difficult to spend time with?',
    "If you're a brand, what's your tagline or mission statement?",
    'What everyday gadget would have been deemed witchcraft in medieval times?',
    'Have you ever lost your keys? Where did you find them?',
    'As a percentage, how happy are you with life right now?',
    'What are you determined to do, no matter what?',
    'When you were a baby, what was the best way to lull you to sleep?',
    'lf you were a bus driver, at what point would you pull away if someone was '
    'running to get on?',
    'What one thing that is impossible today will become possible in the future?',
    'Have you ever lost your mojo? How did you get it back?',
    'What type of clouds are prettiest?',
    'If the story of your life was a book, what would its title be?',
    'What crime today will no longer be a crime in the future?',
    'Do you have a non-negotiable way of assembling a peanut butter and jelly '
    'sandwich?',
    'What road featured in a movie would you most like to take a trip down?',
    'If two items have the same specs and features, what makes you choose one '
    'brand over another?',
    'What everyday item keeps going missing in your home, but no one ever owns up '
    'to having taken it?',
    'Have you ever caught a snowflake on your tongue? When was the last time?',
    'What contraption from the Acme company in cartoons would be coolest to have '
    'in real life?',
    'Have you ever bought or read a self-help book? Which one?',
    "Which kids' TV show has messed up most young minds?",
    'If you were a bottle of wine, what three words would describe you on the '
    'label?',
    'What will the next wearable tech be?',
    'Could you stay off social media for a whole week?',
    'Who is the most inspirational person in your life?',
    "What conversation starter instantly lets you know someone isn't best buddy "
    'material?',
    'Have you ever lost all respect for someone? Who was it and why?',
    'What will you never, ever compromise on?',
    'When you were a child, what did you think you would never do as an adult '
    'that you now do?',
    'lf we colonize the moon, what company will be the first to open for business '
    'up there?',
    "What's the weirdest diet you've ever gone on?",
    'How far would you be willing to commute for the job of your dreams?',
    "If you couldn't find a ruler, what would you use to draw a straight line "
    'with pen on paper?',
    'What household chores did you always do as a child? Did you get paid?',
    "You're going to do a daredevil leap across the Grand Canyon. What mode of "
    'transport will you use?',
    'What type of interior do you like a restaurant to have?',
    'How low can you go when you try to limbo?',
    'When was the last time you stormed out of a room, and why?',
    "If you won a life-changing sum of money, what aspects of your life wouldn't "
    'change?',
    'What clubs or societies have you been a member of that you no longer attend?',
    'Have you ever been a sleepwalker? When was the last time?',
    'What hot food would be the most disgusting if eaten cold?',
    '"It\'s the End of the World as We Know It" is a song title. What event has '
    'made you think this way?',
    'Have you ever said yes when you should have said no?',
    'What will humans look like one million years from now?',
    'How far would you be prepared to travel to buy a hard-to-find item you need '
    'for a collection?',
    'What company or brand are you most loyal to? Why?',
    'If you could turn back time and purchase shares in one company, which one '
    'would it be? Why?',
    'Do you always brush your teeth in the same way?',
    'You have three wishes; what would the third one be?',
    'Do you believe life has been hard on you so far?',
    'What one thing should you never buy used?',
    'When was the last time you did the hokey pokey and where were you?',
    'If there could be only one pasta shape, what should it be?',
    'What type of cheese would you say is the best match for your style and '
    'personality?',
    'Humans share 99 percent of their DNA with chimpanzees. Judging by your '
    'habits, what might others think you share DNA with?',
    'Which TV game show would you most like to be a contestant on?',
    'Is there anything that can beat a cherry on top?',
    'Can you eat a donut without licking your lips?',
    'How long would your whiskers need to be if they were your guide to fitting '
    'your body through a space?',
    "What type of car sends out a message that you're doing well for yourself "
    'without flaunting it?',
    'If you could travel back in time, but you then had to stay there, would you '
    'go?',
    "What's your favorite song with a person's name in the title or lyrics?",
    "Do you agree that size doesn't matter?",
    'What character trait(s) have you inherited from your parents?',
    'If walls could talk, which walls would you like to have a conversation with?',
    'When was the last time you threw caution to the wind and said, “Why not?"?',
    'What was the last thing you were due to go to that had to be canceled or '
    'postponed?',
    'Should there be a Fortnite World Cup?',
    "What cheesy song makes you cry, even though it's lame?",
    'How would you tactfully tell a work colleague they had bad breath?',
    'What one thing should people stop accepting as normal?',
    "If the world wasn't a globe, what shape should it be?",
    'What everyday activity would you like to be able to fast-forward through?',
    "You're going backpacking. What one non-essential item would you carry in "
    'your backpack?',
    'What were you trying to do the last time you wished you had more than two '
    'hands?',
    'When you were a child, where did you think babies came from?',
    "What Ripley's Believe It or Not story do you find most difficult to believe?",
    'Who is the most beautiful person you know?',
    'Is there is a job that one sex can do better than the other? What is it?',
    'What else happened in the world in the year you were born?',
    "You're invited to a themed party and must dress as a character from Star "
    'Wars. What will you wear?',
    'Which TV personality has a face that was meant for radio?',
    'lf you wear shoes with laces, do you always untie them before you take them '
    'off?',
    "What's the weirdest food name you've heard?",
    'If you won a large sum of money in a charity prize draw, would you donate it '
    'to the charity?',
    'What idiom could be used as the opposite of “as the crow flies"?',
    'Do you always treat others the way you would wish to be treated yourself?',
    'What common expression do you find the most annoying when people use it?',
    "You're going away for a weekend break. Which three essentials would you "
    'pack?',
    'Have you ever bought anything at a garage sale? What?',
    "What's your favorite thing about being you?",
    'If the White House had to be a different color, what should it be?',
    "How would you politely deal with food that's too hot in your mouth without "
    'grossing everyone out?',
    'What emoji do you use most?',
    "If the Statue of Liberty wasn't holding a torch, what would you replace it "
    'with?',
    'What are the two most stereotypical North American names?',
    'If you see a big red button, do you want to touch it?',
    "You're freaking out. What do you do to calm yourself down?",
    'If you and your friends had an apple throwing contest, who would throw the '
    'farthest?',
    'What character from a childhood book or movie did you connect with most?',
    "How would you go about explaining American football to someone who's never "
    'seen a game?',
    'What restaurant have you eaten at more than any other, and do you always '
    'order the same meal?',
    'If you could transport a very angry hippo into any point in history, where '
    'would you put it?',
    'You have ten seconds to name three hits by the Beatles. Can you do it?',
    "What's your favorite thing to make with bananas?",
    'Have you ever cheated in a game or a test, and did you get away with it?',
    'What was the last thing you were daydreaming about when you should have been '
    'paying attention to something else?',
    "If the red carpet wasn't red, what color should it be?",
    'During which medical procedure would you least like to wake up from the '
    'anesthetic?',
    'Which two colors do you think coordinate best with yellow?',
    'Have you ever looked in the mirror and not recognized yourself? When was '
    'this?',
    'What were you doing the last time you surprised yourself as well as others?',
    "When was the last time you couldn't stop yawning?",
    'If the sound of you coughing could be replaced with any sound effect, what '
    'sound would you choose?',
    "What color clothing doesn't suit you?",
    'When you were growing up, was there something in your home you were told you '
    'must not touch?',
    'What illness would you pretend to have if you wanted to get out of doing '
    'something?',
    "If you suddenly had an elephant's trunk, who would you spray with water "
    'first?',
    "What's your favorite tongue twister?",
    'Do you agree with the idea that you should do one thing every day that '
    'scares you?',
    "What's the weirdest exhibit you've heard of in an art gallery?",
    "You're jogging in the park and an aggressive loose dog chases after you. "
    'What do you do?',
    'Which two animals would you mix to make a new species?',
    'At what point in life did you know what you wanted to do when you grew up?',
    'What character flaw are you least tolerant of in others?',
    'Have you ever attended an event and felt totally over or underdressed? What '
    'was the event?',
    'What dream or nightmare have you had more than once?',
    'Which household chore do you least like doing?',
    "What helps to recharge you when you're lacking energy?",
    'Which TV show do you think should be more popular?',
    'If the Monopoly board featured your hometown, what two properties would be '
    'the most expensive to buy?',
    'What two words would your work (school) colleagues use to describe your '
    'character?',
    'What houseplant best suits your personality?',
    "What's the worst shopping experience you've ever had?",
    'Do you think cats and dogs understand us if we meow or bark?',
    'What weird place did you fit into as a child that you wish you could still '
    'fit into now?',
    "What reindeer games do you think Santa's reindeer play, and should Rudolph "
    'be allowed to join in?',
    'lf the closest round object is the cause of your death, how do you die?',
    "What's your favorite type of puzzle?",
    'Did you ever have a flip phone? Do you miss it?',
    'What are the top three most used apps on your phone?',
    'When was the last time you wanted the ground to open up and swallow you?',
    'What cargo would be the worst truck spill on a highway?',
    "If the Incredible Hulk wasn't green, what color should he be?",
    'What image would make the toughest jigsaw puzzle?',
    'Have you ever locked the keys for something inside the something?',
    'What was the last thing you waited patiently for? Was it worth the wait?',
    'Do you have a home remedy that you swear by? What is it?',
    'What was your favorite breakfast cereal as a child? Do you still eat it now?',
    'When you were growing up, what job did you want to have?',
    'If you suddenly developed fabulous artistic ability, what would you like to '
    'create?',
    'What one thing is it impossible for anyone to look cool doing?',
    'Should there be a death penalty? Why?',
    '“I\'ve been expecting you, Mr. Bond..." What funny scenario might Blofeld '
    'have been caught in had he not been expecting him?',
    'Is there life after death?',
    'What caused your most recent bruise?',
    'Have you ever looked at strangers around you and imagined their life story?',
    'What donut topping or filling is your absolute favorite?',
    'How do you respond to unwanted advice?',
    'If you could add a made-up word to the dictionary, what would it be and what '
    'would it mean?',
    'What inanimate object in your home would you most like to have a '
    'conversation with?',
    'Have you ever drawn the short straw? What did you have to do?',
    'Where did you go the last time you had an “excellent adventure"?',
    'Do you agree with the ban on heading balls in youth soccer?',
    'Who is the most annoyingly cheerful person you know?',
    'What was the worst punishment you received for misbehaving as a child?',
    'If you could test drive any land vehicle, what would you choose?',
    'What celebrity death has made you emotional?',
    "You're lost in the woods and come to a fork in the path. How do you decide "
    'which path to take?',
    "If the answer is ten, what's the question?",
    'Which herbivore would be the scariest if it became a carnivore?',
    'Can you remember the title of the first book you read on your own?',
    'lf you could trace your ancestry back to someone famous in history, who '
    'would you want it to be?',
    "When was the last time you couldn't read your own handwriting?",
    "You're forming a rock band. What will you call it?",
    'If you woke up tomorrow and discovered you had slept for ten years, what '
    'question would you ask first?',
    'What two things should people never Google?',
    'Have you ever blown a bubblegum bubble that burst all over your face?',
    'What was the last dance move you learned?',
    'If you could taste a rainbow, what would indigo taste like?',
    'What two things do you most like about your job (or school)?',
    "You're entering a best-dressed scarecrow competition. What clothes will you "
    'use?',
    "When you're going on vacation, when do you pack your suitcases?",
    'How would you explain what a meme is to someone who has no idea?',
    'Is there no such thing as a free lunch?',
    'When was the last time you were late for something? What was it?',
    'What was the last food you really craved?',
    'If you could ask Walt Disney one question, what would it be?',
    "What's the weirdest food you've seen cooked on a barbecue?",
    "If you woke up inside the last video game you'd played, what would your "
    'chances of survival be?',
    'Where DNA is available, should extinct animals be brought back to life?',
    "What's your favorite type of takeaway food?",
    'Do you agree that some people are born evil?',
    'What was the last thing you thought was too good to be true?',
    'How low into the red will you let your fuel gauge go before you fill up?',
    'What cartoons do you still watch today?',
    'Do you tear Scotch tape with your teeth?',
    'Baby fat is sometimes called puppy fat. What would be a cute name for adult '
    'fat?',
    'You have one minute to make something out of an empty shoebox. What will you '
    'make?',
    "Do you agree with Malcolm Gladwell's 10,000-Hour Rule, and that deliberate "
    'practice leads to expertise in anything?',
    'Which two colors would you never wear together?',
    'What can you do that other people think you can’t do?',
    'Should theaters be more relaxed, and would you take your shoes off in one?',
    'What incredible fact do you find it most difficult to get your head around?',
    'If you suddenly became deaf, what sound would you miss most?',
    'What\'s your favorite version of "keep calm and carry on"?',
    'How would you design a spice rack for a blind person?',
    'What was the last thing you thought was "a sight for sore eyes"?',
    'If the Pied Piper could lead more than rats away, what one other animal do '
    'you wish had followed him?',
    'What things about life today will people be nostalgic about in thirty years’ '
    'time?',
    'Have you ever lit a campfire? Would you know how?',
    'What can you never have enough of?',
    'If you could switch the sounds two animals make, what two would make the '
    'funniest switch?',
    'What one thing have you seen that you wish you never had?',
    "You're on a sightseeing tour and notice your guide's zipper is down. What do "
    'you do?',
    'At what age does a person become "elderly"?',
    'Who is one of the most intelligent people you know personally? Do you ask '
    'them for information or advice?',
    'What canapés or finger foods should be banned from formal parties?',
    'Have you ever literally danced the night away? What type of dance were you '
    'doing?',
    "You're on the first floor of a store when an earthquake hits. What do you "
    'do?',
    'If you could add one more color to the rainbow, what would it be?',
    'What two things do you always keep by your bed at night?',
    'Have you ever climbed a tree, and if so, when was the last time you did it?',
    'Who is the loudest snorer you know?',
    'What was the last card game you played?',
    'If the Clue (Cluedo) characters were real people, who would be most likely '
    'to get away with murder?',
    'If you only had one day left to live, what would you have for your last '
    'meal?',
    'Does stepping into a position of power change people?',
    "You're creating a photo calendar. What photo do you use for October?",
    'Have you ever accidentally-on-purpose broken something because you hated it? '
    'What was it?',
    'What tense drama would be funniest if turned into a musical?',
    "When's the last time you lied to your parents and why?",
    'Which Harry Potter character would you least like to be sitting next to ona '
    'long-haul flight?',
    'What are the biggest challenges young people face today?',
    'Have you ever been to a school reunion?',
    'Where are you from? Is it where you call home now?',
    'If you see a “wet paint" sign, do you touch the paint to see if it really is '
    'wet?',
    "When was the last time you couldn't get to sleep? What did you do?",
    'What radio jingle sticks in your mind most?',
    'lf you could swap bodies with someone for a day, who would it be?',
    'If you could start a new trend, what would it be?',
    'Can you do a "live long and prosper" Vulcan hand greeting like Spock?',
    'What bug would you least like your home to be infested with?',
    'How would you describe your relationship with money?',
    'What camouflage colors would you need to be able to hide from predators in '
    'your daily environment?',
    'If you could suddenly fly, where would you go first?',
    'What song from a Disney movie sticks in your head most?',
    'Where do all the missing socks go?',
    'Have you ever said "hi" to someone on the street thinking it was someone '
    'else?',
    'What was the last thing you stuck your finger in?',
    'Which two fictional characters would have the most awesome baby if they got '
    'together?',
    'Do you agree that nothing in life is simple? Why?',
    'What ingredients should go into the ultimate one-pot meal?',
    'Have you ever lied about your age? When? Why?',
    '“| would do anything for love, but | won\'t do that," sang Meatloaf. What '
    "wouldn't you do for love?",
    'What\'s your favorite version of the poem that begins “roses are red"?',
    'Is there one color of clothing you own more of than any other? What is it?',
    'What thing did you ask Santa for more than once but never got?',
    'You have no matches or lighters. How will you light the barbecue?',
    'What dog breed should win all canine beauty contests?',
    "How do you make sure you don't forget to do something important?",
    'Have you ever changed a car tire, or would you know how to do it if you had '
    'to?',
    'What question have you only given a half-truthful answer to recently?',
    'If you could start a magazine, what would it be about?',
    "You're on the Star Trek Enterprise and you discover a new life form. What "
    'name will you give it?',
    'What two things (could be anything) would you swap to cause the greatest '
    'chaos?',
    "Do you agree that there's a place for everything and everything has its "
    'place?',
    'What incurable disease would you most like to discover a cure for?',
    'When was the last time you built a sandcastle?',
    "How would you describe the texture of a mushroom to someone who's never seen "
    'or eaten one?',
    'What does success look like?',
    'If you could ask your great-grandparents one question, what would it be?',
    "What's your favorite video game sport to play?",
    'Have you ever lied about what you do for a job? Why?',
    'What small animal would look the most awesome if it became the size of an '
    'elephant?',
    'When was the last time you were on a playground roundabout and did you play '
    'dangerous games on it?',
    "You're directly in the path of fast-flowing lava. How will you escape it?",
    'What one thing gets an unnecessary amount of hate?',
    'If the best things in life are free, what are they?',
    'How would you describe the feeling of being hungry?',
    "What's the weirdest hiccup cure you've ever heard of?",
    'What was the last thing you stitched by hand?',
    "Which type of chocolate in a box is your least favorite, but you'll eat it "
    'anyway?',
    'Have you ever left the key for the door under the mat?',
    'What buzzwords do you find most annoying?',
    'How do you like to eat a creme egg?',
    'If someone you knew was having a panic attack, what would you do to help '
    'them?',
    "What's your favorite way to mix the topping of your frozen yoghurt?",
    "As nervous as a long tail cat in a room full of rocking chairs. What's your "
    'favorite nervous simile?',
    'What are sweet dreams made of?',
    'Is there one person you would give your life to save? Who?',
    'What\'s "the best thing since sliced bread"?',
    'If Star Wars had to be renamed, what would be a good alternative?',
    'What smell always makes you feel hungry?',
    'Should the world be more respectful to politicians?',
    'What does living an “ordinary” life mean to you?',
    "If someone else's life depended on it, could you face your greatest fear?",
    "You're creating a new kids' wear brand. What will you call it?",
    'Which food do you think is the noisiest to eat?',
    'If you witnessed a mugging, what would you do?',
    'How would you describe the feeling of an ice-cream brain freeze?',
    'What caged animal would you least like to clean up after?',
    'Which X-Men mutation would you most like to have?',
    'How would you describe the color of a perfect slice of toast?',
    'What one thing do you wish you had a dollar for every time it happened?',
    'If someone said they would buy your ticket, would you sign up for space '
    'tourism?',
    'What does happiness smell like?',
    "You're asked what your name means. What imaginative but ultimately fake "
    'answer could you give?',
    'Do you have a guilty pleasure and are you willing to own up to it?',
    'What breed of dog is the most ridiculous?',
    'If you could start a business tomorrow, what would it be?',
    'What should be the next hands-free gadget?',
    'Where do you display the most fragile ornament or trinket in your home?',
    "You're out of sugar and you need it for the recipe you're making. What do "
    'you use instead?',
    'When was the last time you yelled at the TV or radio? What about?',
    'You have no corkscrew. How will you open a corked bottle?',
    "What two savory foods wouldn't taste better with a little cheese grated on "
    'top?',
    "lf Sir Walter Raleigh hadn't introduced potatoes to Europe, what other "
    'discovery might he have introduced?',
    'What should the buttons on a gingerbread man should be made of?',
    'If you could be an elite athlete in any sport, which would it be?',
    "What's the weirdest impulse buy you've ever made?",
    'If you no longer needed to go to work, what would you do with your life?',
    "Who is the last person you'd call for help solving a crossword puzzle clue?",
    'Have you ever laughed so hard a little bit of pee came out? When?',
    'What punishment should dog owners be given for not picking up dog poop?',
    'If you needed to pick a lock, what item that you carry with you would you '
    'try using first?',
    'How would you describe a stereotypical Australian?',
    'Where do you hide important or valuable documents in your home?',
    "What's a fair way to split household chores?",
    'Do you have a favorite mug? If so, why is it your favorite?',
    "If you could be someone's pet for a day, who would it be, and what would you "
    'be?',
    'Have you ever run out of fuel in your car? What did you do (or what would '
    'you do)?',
    'When was the last time you blushed and why?',
    'What movie scene still makes you emotional no matter how many times you see '
    'it?',
    'How would you describe an elf?',
    'What two slightly more out of the ordinary things "go together like a horse '
    'and carriage"?',
    "If someone wants to know what kind of music you're into, what answer do you "
    'give?',
    'Did you ever tease or bully anyone at school?',
    'If Santa had an extra reindeer, what would its name be?',
    'Which word in the English language is the most beautiful?',
    'Have you ever accidentally dropped something into the toilet and had to fish '
    'it out? What was it?',
    'If you were Willy Wonka, what candy would you invent next?',
    "What's your favorite weather?",
    'If someone says, "Don\'t look now..." do you always look?',
    'What bug would freak you out most if it landed on you?',
    "You're planning a first date. Where's a good place to go?",
    'What movie would have been better with a different actor in the lead role?',
    'Who or what makes you smile most?',
    "What's a good example you've seen of older not being wiser?",
    'lf you were walking through a forest and suddenly saw a bear, what would you '
    'do?',
    "Where's the noisiest place you've been, and what was making the noise?",
    'How would you deal with an angry chihuahua refusing to let you enter a '
    'building?',
    "Where's the best place you ever found to hide in a game of hide-and-seek?",
    'Is there one thing your parents did that you said you will never do?',
    'What does fresh air smell like?',
    'Do you agree with big game hunting? Why?',
    'What shoes or boots featured in a movie would you most like to try wearing?',
    'Have you ever borrowed something and not given it back? What was it?',
    "What's your favorite word or phrase for breaking wind?",
    'If you could snap your fingers and change one thing about yourself, what '
    'would it be?',
    "You're an award-winning dancer. What type of dance do you do?",
    "What was the last thing you started and then wished you hadn't?",
    'A hypnotist has convinced you that you can only move by hopping like a '
    "kangaroo. What's the toughest part of your day?",
    'What business should provide a drive-thru service?',
    'You have five hundred emails and no time to open them all. How do you decide '
    'which ones to open first?',
    'What BMX jump is the coolest?',
    "What's your favorite word to describe someone who is drunk?",
    'If you could sit on any sofa featured in a movie or TV show, which one would '
    'it be?',
    'What music at your funeral would make your loved ones laugh?',
    'Who do you want to save the last dance for?',
    'When you achieve a goal, do you always set another one?',
    'If you were to shrink an inch every time you checked your phone today, how '
    'tall would you be by bedtime?',
    "You're all out of salt and pepper. What do you use for seasoning?",
    'Who is the last person you would ask for fashion advice?',
    'Do you have a favorite meme? What is it?',
    "If something you'd borrowed from a friend got broken while you had it, what "
    'would you do?',
    'What one thing do you wish there was more of?',
    'Have you ever roasted chestnuts on an open fire, and when was the last time?',
    'What are some words or phrases that are unique to your town or region?',
    'If you needed to hide candy from someone at home, where would you put it?',
    'What two questions would you ask someone you just met to learn the most '
    'about them?',
    'Should the sale of dinosaur bones in auctions be stopped? Why?',
    'What does family mean to you?',
    "Which five people do you spend the most time with when you're not at work "
    '(school)?',
    'Which book should everyone read at least once?',
    'Did you ever try to find the pot of gold at the end of the rainbow?',
    'What movie would you watch if you wanted to have a good cry?',
    'Who is your favorite Ninja Turtle?',
    "Where's the safest place to stand if you're outdoors in a lightning storm?",
    'lf someone offered you a million dollars for your super-affectionate pet '
    'cat, would you take it?',
    'What bionic body part would you most like to have?',
    "You're running for your life and leap over a wall. What do you hope is on "
    'the other side?',
    "Where's the best seat in the cinema?",
    'Have you ever knowingly broken a law?',
    'What brand of chocolate do you prefer and why?',
    'If your sense of smell was ten million times stronger for one day, where '
    'would you avoid going?',
    'What pseudoscience annoys you most and why?',
    'Who is your biggest hero?',
    'How would the Teenage Mutant Ninja Turtles series be different if the '
    'turtles were middle-aged?',
    'What was the last thing you stapled together?',
    'lf you could be a teacher of anything, what would it be?',
    'What one thing do you regret not doing?',
    "What's the weirdest interior or theme you've heard of a restaurant having?",
    'If you needed glasses or new frames, what style would you choose?',
    "What's a recipe for disaster?",
    'What nursery/kindergarten song would sound cool as a heavy metal song?',
    'Where is the happiest place on the planet?',
    'Have you ever jumped into water fully clothed?',
    "Where's the weirdest place someone might have been when they heard JFK was "
    'shot?',
    'Can you say, “How much wood would a woodchuck chuck if a woodchuck could '
    'chuck wood?" in full?',
    'What belief do you have that other people find weird?',
    'If you could be invisible for one hour, where would you go? And what would '
    'you do?',
    "What's your favorite zoo animal?",
    "You're about to plant a vegetable garden. What's the first thing you want to "
    'grow?',
    "What's one important life lesson you've learned?",
    'Have you ever knowingly bought a fake designer item? What was it?',
    'What music track would you play on a loop to get rid of everyone at the end '
    'of a house party?',
    'Is there something about your physical appearance that you try to hide or '
    'disguise? What is it?',
    'What two names should parents not be allowed to name their children?',
    "How do you pass the time when you're waiting in a long line for a theme park "
    'ride?',
    'If someone else had to make all your decisions for you, who would you want '
    'it to be?',
    'When was the last time you attended a wedding and did everything run '
    'smoothly?',
    "What's fun as a spectator but not as a participant?",
    'If you needed a watertight alibi for your whereabouts last night, who would '
    'give it?',
    'What one thing do you need to make your life easier?',
    'Have you bought an item recently that you had to return? What was it and '
    'why?',
    'When you close your eyes, what can you see?',
    "If red wasn't hot and blue wasn't cold, what colors should be used as "
    'indicators?',
    'What does being "outdoorsy” mean to you?',
    'How old were you when you had your first coffee?',
    "What's the weirdest item you've absentmindedly put in totally the wrong "
    'place?',
    'If you were to be buried with items you might need in the afterlife, what '
    'three items would you choose?',
    'What promise have you made and then broken?',
    "You're setting up a new picture framing business. What will you call it?",
    'Who or what was the last person or thing to make you feel angry?',
    'Are you able to say no, even when it will make you unpopular?',
    'What was the last thing you saw that made you feel squeamish?',
    'If scientists discovered a way to travel through time and the death rate was '
    'one in one million, would you travel?',
    'What boo-boo from your childhood can you still remember today?',
    'Do you agree with Andy Warhol that everyone gets fifteen minutes of fame?',
    'What does Christmas mean to you?',
    'How old were you when you had your first crush, and who was it?',
    'What band or singer that no longer tours would you most like to have seen '
    'perform live?',
    'If snow could fall in three different colors, which ones would you choose, '
    'and why?',
    'Do you agree that some questions are best left unanswered? Which ones?',
    'What mind-blowing statistics do you know?',
    'Have you ever judged a book by its cover and found you were wrong?',
    "Where's your tickle spot and what happens if someone finds it?",
    "You're a sculptor and you've been commissioned to create a piece for your "
    'town center. What will it be?',
    'What bad omens do you believe in?',
    'Earth, air, fire, water: do you know which astrological element you are?',
    'What movie did someone spoil for you by telling you the ending?',
    "If you need to lift a friend's spirits, wnat do you do?",
    'What two important things did your mom teach you?',
    'You have broken both arms and need help to eat. What food would you not want '
    'to be fed?',
    "What's your go-to non-cuss word if you drop something on your toe?",
    'Who is the humblest person you know?',
    'If you could shapeshift into three things, what would those things be?',
    'What playground games did you play as a kid?',
    "Where is the most beautiful beach you've visited?",
    "What's Switzerland most famous for?",
    'Should the baggage allowance on flights include the weight of the passenger?',
    'Which fictional baddie is the "baddest" of them all?',
    'What are some unwritten rules in society today?',
    'If rain could have a flavor, what would you want it to be?',
    'Have you ever hurt or broken a tooth biting into something, and what was it?',
    "Where's the most exotic place anyone could spend their childhood years?",
    'What mispronunciation irks you or makes you laugh the most?',
    'If one part of your body could be detachable, which part would you choose?',
    'Would you sell a kidney if you needed the money?',
    'If you could be the face of a brand or product, what would it be?',
    "What's your hometown most famous for?",
    "You're Simon Cowell and you're creating a new boy band. What will it be "
    'called?',
    "What's the best age to get married?",
    'Have you ever been totally prepared for something, only to discover you were '
    'prepared on the wrong day?',
    'What one film have you not seen that it seems everyone else in the world has '
    'seen?',
    'If pets gave their owners names, which three names would be most popular?',
    'ls there something we believe to be a fact today that will turn out not to '
    'be?',
    'Under what circumstances will you give up your seat to someone else on '
    'crowded public transport?',
    'What was the last thing you saw or heard that made your jaw drop?',
    'How do you like to eat a Twizzler?',
    'If you could send a message in a bottle right now, what would it be?',
    'What line would you like to add to the "If You\'re Happy and You Know It" '
    'song?',
    'When was the last time you ate your all-time favorite food?',
    'If you were the star of a show, who or what would your sidekick be?',
    'What does a perfect Sunday afternoon look like for you?',
    'Have you (or do you) organized your pens or crayons by color?',
    "What's the weirdest item you've heard of someone shoplifting?",
    'lf you could be the opposite sex for one day, what would you want to do?',
    'What two famous stage names can be combined to create an awesome new stage '
    'name?',
    'What was your lowest performing subject at school? Did you ever fail a '
    'subject?',
    'What one question do you hope no one ever asks you?',
    'Where was the biggest waterfall you ever saw?',
    'What old-fashioned baby name is least likely to come back into fashion?',
    'Have you ever checked under the bed before getting into it? What were you '
    'checking for?',
    'What baby animal do you find the most adorable?',
    'If you were the fashion police, what item of clothing would you ban forever?',
    'What noise would make a hilarious car horn?',
    'How old were you when you had the best birthday cake ever?',
    'If you could see behind the scenes, which celebrity would be the most boring '
    'when not performing?',
    'What does "dress to kill" mean to you, and what did you wear last time you '
    'did it?',
    'Do you have a favorite Christmas movie that you watch every year?',
    'What one thing do you need to get done today?',
    "You're a karate chop superstar. What amazing item can you split in half?",
    'What musical instrument is the coolest to play?',
    'Who or what was the last thing that intimidated you?',
    'What does "a life well lived" mean to you?',
    "You're starting a new blog. What's it about and what will you call it?",
    'Which famous person would you most like to go shopping with?',
    "What's your favorite Super Bowl food? What items should you always have on a "
    'Super Bowl party menu?',
    'If you must lose all memories of your life except one, which one would you '
    'want to keep?',
    "What's your idea of a perfect TV dinner?",
    'Which profession today is no longer as respected as it once was?',
    'How do you hide your emotions?',
    'What was the last thing you said to yourself inside your head?',
    'Could you talk someone through how to tie a shoelace without using your '
    'hands to demonstrate?',
    'What should go on the top of a Christmas tree?',
    'How old does an item need to be before you consider it to be a "vintage" '
    'piece?',
    'What one thing do you do to reduce the level of stress in your day?',
    'Have you ever howled at the moon?',
    "Where was the last place you got stuck for hours and thought you'd die of "
    'boredom?',
    "What's the best feeling in the world?",
    'If one letter had to go missing from your keyboard, which one would you like '
    'it to be?',
    'What routine medical examination do you dread most?',
    'Who or what was the last thing you physically applauded?',
    'Beyond spending, what other things have you done with your pennies?',
    "What's your kryptonite?",
    'How do you celebrate Independence Day and do you do the same every year?',
    'What twenty-first-century expression is a good update for "burning the '
    'candle at both ends"?',
    'lf you could replace the Mount Rushmore heads with those of four people in '
    'your life, whose would you choose?',
    'Should students be allowed to choose which books they read in English '
    'classes?',
    'What awkward happening have you had to style your way out of recently?',
    'Does opportunity only ever knock once?',
    "What's your favorite Starbucks drink and why?",
    'If you were the BFG, what dream would you like to bottle?',
    'What was the last thing you read out loud, and why?',
    'Have you heard of Moonpig? What would you name your rival online greeting '
    'cards business?',
    'Who is the greatest sportsperson of all time, and why?',
    "Is there something you do (or don't do) that other people find hard to "
    'understand or accept?',
    'What song makes you feel like dancing every time you hear it?',
    'When was the last time you ate a panini and what filling did you have?',
    'You have been asked to name a new super-powerful firework. What will you '
    'name it?',
    'What are fishing garden gnomes fishing for?',
    'If you could roar like a lion, when would you do it to have the biggest '
    'impact?',
    "What's the best thing about getting older?",
    'When you flip a coin to choose between two options, do you always make the '
    'same Call?',
    'What spam email do you receive most often?',
    'Where was the last place you stayed on a family vacation?',
    "What job would you like to be able to do but know you wouldn't be any good "
    'at?',
    "You're the host of a new daytime talk show. Who is your first guest?",
    'What sound would you like to have as a doorbell?',
    'If you could change one thing you did or said today, what would it be?',
    "What's your most enduring pet peeve?",
    'Have you dressed up for World Book Day? What book character would you dress '
    'as now?',
    "What do you yell when you're in a location with an echo?",
    'Do you know how to change a lightbulb, and when did you last do it?',
    "What's the biggest difference in culture between North America and the "
    'United Kingdom?',
    'If you met an alien, what would you say?',
    'What sound should a reversing truck make to ensure everyone gets out of the '
    'way?',
    "You're a human by day and another creature by night. What other creature "
    'would you be?',
    "Who or what were you into last year that you're so not into this year?",
    'What item in your fridge today has been in there the longest?',
    'Under what circumstances are you most impatient?',
    'What song of today will be a golden oldie twenty years from now?',
    "If you could change a fictional story line so a character wouldn't die, "
    'which story line would it be?',
    'Have you ever haggled for a better deal? Were you successful?',
    'If one of your internal organs had to be external, which one would you want '
    'it to be?',
    'What stage show would you most like to get tickets for?',
    'Have you ever had, or would you consider having cosmetic surgery?',
    'What\'s your most ridiculous "first world problem"?',
    'How often do you step outside of your comfort zone? When was the last time?',
    'What TV-show kitchen would you most like to have?',
    'If you could plant a tree in your garden, what type would you choose?',
    "What's the bravest thing you've ever done?",
    'Do you have a birthmark on your body? Where is it?',
    "What's the weirdest pregnancy craving you've ever heard of?",
    'lf you could be the drummer in a band, which one would it be?',
    'What one thing do people procrastinate over more than anything else?',
    "Have you heard of Klingon and Na'vi? What fictional or constructed language "
    'would you like to be able to speak?',
    "What do you wish you'd invented?",
    'lf you lost your sense of smell, what smell would you miss most?',
    'Which famous person is the exact opposite of you?',
    'How old do people think you are?',
    'What sport requires the highest level of fitness?',
    'If Peter Rabbit had to be renamed, what would you call him?',
    'What was the last thing you pinned on your fridge door?',
    'Did you give your first car aname (or what would you name your first car)?',
    'How do you eat an Oreo?',
    'What studio audience would you most like to be in?',
    'Where was the last place you traveled to by bus and did you talk to any '
    'other passengers?',
    'What Jell-O flavor should be introduced?',
    "Is there something you know about someone that they don't know you know?",
    'What still-to-be-written bestseller would you like to be the author of?',
    'When you get a gut feeling or hunch about something, are you usually right?',
    "What's the first sign of madness?",
    'If you lost your phone, how many phone numbers would you know by heart?',
    "What would your friends say you're a little snobbish about?",
    'When was the last time you asked someone for directions?',
    'What stereotypical belief about your country is not true?',
    "You're a fearless BASE jumper. What landmark or building will you jump from "
    'next?',
    'What do you wish you could do every day?',
    'Have you ever had your mind blown by a logic puzzle? What was it?',
    'What item of clothing would you rather die than be seen wearing in public?',
    'If you were required by law to have a body piercing, what would you pierce?',
    'What would your day be like if you switched places with your pet?',
    'Which products have the weirdest TV commercials?',
    'What was the last thing you overreacted to and blew up out of proportion?',
    'How many 1980s pop stars can you name?',
    "What's your main goal in life?",
    'How often do you listen to classical music and who is your favorite '
    'composer?',
    'What technology will replace smart phones?',
    'Should schools have classroom pets?',
    'What do you wish you could bottle?',
    'Do you agree that you can have too much of a good thing? Have you '
    'experienced it?',
    "What's the weirdest load you've seen on the back of a truck?",
    'If one color had to be removed from the rainbow, which one should it be?',
    "What's your opinion of people who wear shades indoors?",
    'Have you ever had to wear a uniform to work (school), and what was it?',
    'What tastes weird after eating a mint?',
    'If you could be world champion at something, what would it be?',
    'What app do you open most on an average day?',
    'Who is the greatest person to have ever lived?',
    'What style of hat suits you best?',
    'You have acquired a racehorse. What will you name it?',
    'What would you say to someone if you really wanted to confuse them?',
    'If you could own any type of car, what would you choose?',
    "You're the maker of world-famous pies with a secret ingredient. What is that "
    'secret ingredient?',
    'Who should be the next James Bond?',
    'Author Roald Dahl created alien creatures called "vermicious knids."” What '
    'alien creature name can you think up?',
    'What assumptions have people made about you that are totally wrong?',
    "You're a famous pop star known by just one name. What is it?",
    'What will be the next big scientific breakthrough?',
    "Who should have a star on Hollywood's Walk of Fame?",
    'Do you agree that sorry is the hardest word?',
    'Where were you when you saw the prettiest sunset?',
    'What one thing could you change to start saving money?',
    'If you were reincarnated as a non-living thing, what would you want to be?',
    "What aspect of your country's heritage are you most interested in "
    'preserving?',
    'Have you ever completely lost track of time? What were you doing?',
    'What parenting behaviors do you believe negatively affects children?',
    'What would be an awesome supermarket own-brand copycat name for Pop- Tarts?',
    'If you could change one thing about the last hour, what would you change?',
    'Tom Hanks and Ozzy Osbourne arrive at your door in a hurry. What do they '
    'want?',
    'Can you do mental arithmetic?',
    "What's your opinion on arranged marriages?",
    'If you were starving, would you eat roadkill?',
    "What were you into as a teenager that you thought you'd always be into but "
    'then lost interest?',
    'Have you ever had to return a meal served to you in a restaurant? Why?',
    'What product name would you give to the opposite of Gorilla Glue?',
    'If you lived in Candyland, what would you like trees to be made of?',
    "What's the most distant place from your home that you've visited?",
    'What person from history would you most like to have shaken hands with?',
    'Why?',
    'If you were Puss in Boots, what style of boots would you wear?',
    'Have you ever had to fish something out of the trash? What was it?',
    'Is there something you do in a quirky way compared to other people?',
    'What aspect of life before the internet do you find hardest to imagine (or '
    'remember if you were there)?',
    "At five foot eight you'd be the height of a London black cab. What can you "
    'compare your height to?',
    'If not you, who or what has this been an amazing week for?',
    'Which famous person attracts the worst type of fan?',
    'When you meet friends in a coffee shop, do you always sit at the same table?',
    'Why?',
    "If you knew you wouldn't get caught, would you break the law, and which law "
    'would you break?',
    'What song from a musical did you last sing, and what were you doing at the '
    'time?',
    'How often do you connect with nature? How?',
    "What do you wish people wouldn't eat on the street?",
    "You're the owner of a company famed for its funky packaging. What makes it "
    'funky?',
    'What was the last thing you made up an excuse to get out of doing?',
    'Have you ever had to put someone into the recovery position? Do you know how '
    'to do it?',
    'What thoughts have been at the forefront of your mind today?',
    'If you could own a famous work of art, what would you choose?',
    "What TV show's final episode was the biggest disappointment to you?",
    'What are your views on facial recognition technology in schools and on the '
    'street?',
    'Have you ever ridden a horse? Where and when?',
    'What would your pirate name be?',
    'You have a six-hour delay at the airport before your next flight. How do you '
    'pass the time?',
    'If not the "big bad wolf," what other animal should have been big and bad in '
    'fairy tales?',
    'What do you usually share on social media?',
    'Does there need to be evidence before something can be a truth?',
    "What's the most unusual building material you could use to build a house?",
    "Where were you when you were the coldest you've ever been?",
    'If not you, which one of your friends eats a KitKat in the most annoying '
    'way?',
    'What TV show would you get bored with fastest if it was the only one you '
    'could watch?',
    'Do you fit the stereotypical image of someone from your country? In what '
    'way?',
    'What kind of earphones do you prefer and why?',
    'Have you ever had to evacuate a building because the fire alarm went off?',
    'Did you have a favorite place to go when you were a kid, and when did you '
    'last go there?',
    'What do you wish could be recycled?',
    'If you could organize a good deed project in your neighborhood, what would '
    'it be?',
    'What made-up word would you like to see added to the dictionary?',
    'When was the last time you agreed with the statement “less is more"?',
    'What precious possession would you be most sad about if you broke it?',
    'Do you find it hard to talk about death in your family?',
    'What was the last thing you learned how to do by watching YouTube?',
    'How often do you wash your jeans?',
    'What are your views on animal testing in scientific research?',
    'Have you heard of International Talk Like a Pirate Day? What international '
    'day would you like to create?',
    "What's your star sign and do you have the associated character traits?",
    'If you inherited five hundred acres of land, what would you do with it?',
    'What kitchen gadget do you have that you never use?',
    'Did you ever dream of marrying a fictional character? Which one?',
    'What do you think would happen if you fell into a black hole?',
    "You're the ruler of a brand-new country. What colors and design will you "
    'choose for your national flag?',
    "What's the worst job in the world?",
    'Have you ever had to chase after something that got blown away in the wind?',
    'What was it?',
    'What animal looks way too cute to be as deadly as it is?',
    "Help! There's no toilet paper! What do you use instead?",
    'Who is the funniest comedian of all time?',
    'What one thing can you say with certainty you will never do?',
    "You're a boxing champion. What music accompanies you into the ring?",
    "What's your spaghetti eating technique?",
    "Is there something you're good at but you'd rather not be?",
    'If not Nemo, what would be a great name for a clown fish?',
    'What are your views on CCTV cameras in school classrooms?',
    'Does modern technology complicate life? Why and how?',
    'Which family member are you closest to, and has it always been this way?',
    "What's the worst part of having a cold?",
    'If you were presented with a music award, what genre of music would it be '
    'for?',
    "What movie is so spectacularly bad that it's almost good?",
    "Time is a great healer, but what can't it heal?",
    'What line would you like to add to the "Wheels on the Bus" song?',
    'Where would you like to be living in twenty years?',
    'What artificial fruit flavor is least like the real flavor?',
    'How often do you meet the five-a-day fruit and vegetable target, and how do '
    'you do it?',
    'What have you committed to doing to save the environment?',
    'Where will Banksy strike next?',
    "Have you ever considered yourself to be someone's number one fan? Whose?",
    'What do you think happened to the crew of the Mary Celeste?',
    'lf you hyphenate the name of your first pet with your family name, what '
    'showbiz name do you get?',
    'What fruit do you always take from the bowl first?',
    'Should relationships always be prioritized over careers?',
    "What's the weirdest reason for a traffic hold-up you've come across?",
    'If you could only study three important subjects to learn at school, what '
    'would they be?',
    'If you could change the outcome of one big event in history, what would it '
    'be?',
    'What fitness-wear fashion do you hope never comes back around?',
    'When you show your true colors, what colors are these?',
    'Andy Warhol had twenty-five cats named Sam. What would you call your '
    'twenty-five cats?',
    "What's the ultimate rich-boy's toy?",
    'Who was the last person to give you a wedgie? When and where?',
    'How often do you jump to conclusions without knowing all the facts?',
    'What movie title would be funniest if the word "die" was replaced with '
    '"dance"?',
    "You're trapped in your car in a snowstorm. What do you do?",
    'What six famous people (past or present) would make the most boring dinner '
    'party guests?',
    'If you could only speak the truth for a day, who would you try to avoid?',
    'What new pasta shape would you like to see introduced?',
    'When was the last time that you had to admit you were wrong, and why?',
    "What do you think the world's population will be in the year 2090?",
    'Have you heard of Dog Bark Park Inn or The Big Duck? What other oversized '
    'thing could you make into a building?',
    'What TV show theme song from long ago remains the most memorable for you?',
    'How do you behave when you lose your temper?',
    'What job from the past that no longer exists would you like to have tried?',
    'You work on the hundredth floor of an office building and all elevators are '
    'out for a week. What do you do?',
    'What kind of tail would you like to have?',
    'What movie remake should never have been made?',
    'If you could only see shades of gray and one color, which one color would '
    'you want it to be?',
    'What was the last thing you had to leave work (or school) early for?',
    'Who is the biggest IT dinosaur you know?',
    "What's the saddest sound?",
    'If you could change the color of the sky from blue to any other color, which '
    'would you choose?',
    "What's Rodin's The Thinker thinking about?",
    'How often do you change your screensaver and what is it right now?',
    'What are your three favorite things about where you live?',
    'If you have a fly in your home, do you get rid of it? if so, how?',
    'What habits could you not tolerate a roommate having?',
    'You have a private island. What do you call it?',
    'What\'s your stock response to the question "How are you?"?',
    'Did you have a time-out spot in your home, and did you go there often?',
    'What kitchen gadget that used to be all the rage no longer exists?',
    'Have you binged on a box set recently? Which one?',
    'What do you think lies at the bottom of the Oak Island Money Pit?',
    'Do you find it easy to make new friends?',
    "What's the weirdest thing money can buy?",
    'Have you ever had something run out of battery at an inconvenient time?',
    'What was it?',
    'What was the last thing you heard or saw that made you roll your eyes?',
    'What should happen to your belongings after you die?',
    'Have you ever had a wish come true? What was it?',
    'Where would you like to go on your honeymoon (or second honeymoon)?',
    "What's one thing not very many people know about you?",
    'If you were part of a Russian doll (nesting doll), which layer of the doll '
    'would you want to be?',
    "What's your top three list of the cutest animals in the world?",
    "Do you sing out loud when you're listening to music?",
    'Which TV show is the most overrated?',
    "You're under threat at home. What do you grab to defend yourself with?",
    'What new musical instrument could you invent by combining three existing '
    'instruments, and what would you call it?',
    "Is there something you've done that you would strongly advise others not to "
    'do, and what is it?',
    "What's the weirdest road sign you've ever seen?",
    'Have you ever had an imaginary friend? If you had one now, what would their '
    'name be?',
    'What have you discovered recently that more people should know about?',
    'Who was the last person to ruin your day and how?',
    'What potentially life-threatening allergy would you least like to have?',
    'You will be spending your next birthday alone. Will you celebrate it?',
    'What animal and sound would you like to add to "Old MacDonald Had a Farm"?',
    'If not white stripes on black, what color should pedestrian crosswalks be?',
    'What one thing can you say with absolute certainty you will never own?',
    'How many addresses have you lived at?',
    'What would be the funniest name for a new driving school?',
    'If you could only say one word for the rest of the day, what would you like '
    'that word to be?',
    "What's something you once thought only you knew, then you discovered "
    'everyone knew?',
    "There's a toilet museum in South Korea. What's the weirdest museum you've "
    'visited or heard of?',
    'Which creepy movie has the creepiest music?',
    'What would be a great new costume idea for The Masked Singer?',
    'When was the last time something totally unexpected happened to you, and '
    'what was it?',
    'If you have to pick a number between one and ten, do you always pick the '
    'same one?',
    'What are your thoughts on car eyelashes?',
    'Does life begin at forty?',
    'What were you doing the last time you gave up and stopped doing it?',
    'Who was the last person you called instead of texting or messaging?',
    'If not Rachel, Monica, Phoebe, Ross, Chandler, and Joey, what names should '
    'the characters of Friends have?',
    'What large animal would be the cutest if it became the size of a mouse?',
    'Have you ever had a tick? Do you know how to remove one?',
    'What do you think is the secret ingredient in Coca-Cola?',
    'Do you know anyone with more than one middle name? Who do you know with the '
    'longest full name?',
    'What song has been ruined by being used in a commercial?',
    'When you were a teenager, what were the coolest kids into?',
    'lf you have a bucket list, do you add new things as others are achieved?',
    'What one thing can no one make like your mama used to make it?',
    'Have you ever had a pillow fight? When was the last time?',
    "If not like a rocket, how do you move when you're running as fast as "
    'possible?',
    '“Don\'t be evil" is Google\'s official motto, What alternative motto would '
    'you give the company?',
    'What are your thoughts on euthanasia? Should it be legal?',
    "You're writing a crime novel. In what ingenious way does the murderer poison "
    'the victims?',
    "What do you think is the secret behind the Mona Lisa's smile?",
    'Have you ever closed your eyes and stuck a pin in a map to choose your '
    'vacation destination? Would you?',
    'What TV show do you prefer to watch on your own, and why?',
    'If you have a dishwasher, do you always stack it in a precise way?',
    "What's your top tip for avoiding tears when chopping onions?",
    'How different would your life be without Post-it Notes?',
    'What had you done the last time someone said they were disappointed in you?',
    'Where would you most like to be given a private guided tour?',
    'What would you not do, even if you were offered $10 million to do it?',
    "You wake up on the day of your wedding and can't go through with it. What do "
    'you do?',
    "What's the weirdest sports superstition or locker-room ritual you've heard "
    'of?',
    'Should people be allowed to keep any treasure they find?',
    'What lesson in life have you had to learn the hard way?',
    'Is your life today better than life was for your parents at the same age?',
    'What TV show do you plan your day around to be able to watch it live?',
    'Do you agree that you can "never say never"?',
    "Who is the biggest hypochondriac you know, and what's the craziest disease "
    'they thought they had?',
    "Where's the most haunted-looking house you've ever seen?",
    'If you could change the sound of police sirens to something more fun fora '
    'day, what sound would you choose?',
    'What are you very enthusiastic about that those around you find dull?',
    'Have you ever had a personal trainer? What would your goal be if you had '
    'one?',
    'What fruit juice combination would you like to create and what would you '
    'call it?',
    'If you had your own TV show, what would the theme song be?',
    'What posters did you have on your bedroom wall when you were growing up?',
    'You have a pimple on the end of your nose. Do you squeeze it?',
    'What do you think happened to Amelia Earhart?',
    'lf you were Mr, Potato Head, which attachments would suit your mood today?',
    'Can you create an armpit fart, and can you play a tune?',
    'What are your ASMR (brain massage) triggers?',
    'How many animals can you name that begin with the letter R?',
    'Where would you say your happy place is?',
    'What gadget from a sci-fi movie would be the coolest to have?',
    'If you could only listen to one song for the rest of the week, what would it '
    'be?',
    'What was the last thing you had to apologize to someone for?',
    'Do you know anyone who was named after a famous person?',
    "What's your top tip for getting pets (or children) to take medication they "
    'refuse to take?',
    'If you were knocked unconscious at home, how long would it be before someone '
    'found you?',
    'What truth do you never want to know?',
    'Are video assistant referees ruining sports action?',
    'What life skill should all high school students be taught?',
    "You're writing a children's book about the adventures of a hen. What will "
    'you name the hen?',
    "What one piece of advice have you been given that you've passed on to "
    'others?',
    'Have you heard of Carhenge? What other items could you make into a '
    'Stonehenge replica?',
    'What footprints would you least like to see outside your tent in the '
    'morning?',
    'If you had your own country, what would you call your currency?',
    'What do you think is "so last year"?',
    'You suspect someone you know is involved in a crime. Would you report them '
    'to the police?',
    'Who was the last person you had a staring contest with? Did you win?',
    'What animal and its attributes would you like to add to the Chinese zodiac?',
    'How often do you change your phone case?',
    "What's been your hardest goodbye?",
    "Has there ever been a fashion trend you wouldn't wear because you looked "
    'ridiculous?',
    "What's your top tip for cleaning windows without leaving streaks?",
    'If not Gorilla Glue, what other animal might be a good match for the '
    'product?',
    'You are somehow teleported six feet to the right of where you are now. Would '
    'you survive in that location?',
    'What are you superstitious about?',
    'Have you ever had a nickname? What was it?',
    "What's been the highlight of your month so far?",
    'Who was the last person you high-fived?',
    "You receive a package. It has the correct address but the name's unfamiliar "
    "and there's no return address. What do you do?",
    'Which comedy duo is your all-time favorite?',
    'When you were growing up, what made you think your parents really did have '
    'eyes in the back of their head?',
    'If you could change three things about your life, what would they be?',
    "What are you so spectacularly bad at doing that it's almost impressive?",
    "Do you agree that there's no place like home?",
    'What was the last thing you got into an argument about?',
    "It's karaoke time! What will you sing?",
    'Which member of your family is the worst driver?',
    'If you could only keep one of the chairs you have at home, which one would '
    'it be, and why?',
    'What food or drink did your mom always make for you when you were sick?',
    "You step out of the shower and there's no towel. What do you use to dry "
    'yourself?',
    'When was the last time something happened that made you think it’s a small '
    'world?',
    'What line from a movie do you like to use?',
    'Have you ever had a pen pal? Where did they live?',
    'If you were in Seinfeld, which character would you be?',
    "What's your top tip for peeling a pineapple?",
    'You have a boat that needs a name; what will you call it?',
    'If a friend asked for an honest opinion, would you give it—no matter what?',
    'What do you say when you make a toast with a drink?',
    'Have you ever had a Nerf gun battle? When was the last time?',
    'If not gold, what would be the most awesome thing the Midas touch could turn '
    'things into?',
    "What tune would you like your washing machine to play to let you know it's "
    'done?',
    "Should parents ask for their child's permission before posting photos of "
    'them on social media?',
    'What do you spend way too much time on?',
    "There's a scratching sound coming from your garbage can. What do you least "
    'want to find in there?',
    'What pose would you like to be in if you were turned to stone?',
    'If you could only have one pair of shoes (or item of footwear), which would '
    'you choose?',
    'What one thing are you glad you will never have to do again?',
    'Do you agree that the book is always better than the movie?',
    "What's the weirdest survey you've ever been asked to take part in?",
    'Have you ever completed an online study course? On what topic?',
    "What's the best way to make and serve hot chocolate?",
    'If you had unlimited funds and time, what five countries or places would you '
    'visit first?',
    'Which musical instrument do you dislike the most?',
    'What one person in your life can you always make time for?',
    'If you had your own advice column, what sort of questions would you like to '
    'answer?',
    "What's the best type of sausage?",
    'Who was the last person you sent a picture to? What was the picture?',
    'What\'s your best "class clown" story?',
    'You only have time to grab one possession from your home. What is it?',
    'What do you own (or have owned) with your name engraved on it?',
    'Can you remember your first slumber party? Who came?',
    "What's the biggest crowd you've been in, and where were you?",
    'How often do you change the color scheme or rearrange the furniture in your '
    'home?',
    "What's the biggest family dinner or dinner party disaster you've ever had?",
    'Who is the biggest drama queen you know?',
    "What food is more effort to eat than it's worth?",
    'Have you got a name for sneezing and farting at the same time?',
    'What are you saving up for?',
    'What trimmings go best with a roast dinner?',
    "Do you agree that there's an exception to every rule?",
    "What's a suitable punishment for people who drink from the milk carton and "
    'then return it to the fridge?',
    'How many bands with four members can you name?',
    'What was the last thing you fixed?',
    'Have you ever had a black eye? When and why?',
    'Have you ever had (or do you have) a collection of something? What?',
    'What do you put salt on?',
    'Who was the last person you spoke to on a landline?',
    'What food do you always put tomato ketchup on?',
    'If you were in a movie, who would you most like to walk off into the sunset '
    'with?',
    "You're writing a crime novel. Where will the serial killer hide the bodies?",
    "What always cheers you up when you're having a bad day?",
    'If you had to work in sales, what product would you least like to sell?',
    'When you were little, did you think the moon was made of cheese?',
    'A Milky Way bar in the US is a Mars bar in the UK. What other product name '
    'changes do you know of?',
    'When was the last time someone really surprised you, and what did they do?',
    'If you could only have one flavor of potato chip for the rest of your life, '
    'what would it be?',
    "What's the best T-shirt slogan you've ever seen?",
    'Were you, or anyone you knew, into the emo scene?',
    'Which nursery rhyme character can you most identify with?',
    'How much time would you save if you could teleport to and from work (or '
    'school)?',
    'What trend did you desperately want to follow when you were younger but your '
    "parents wouldn't let you?",
    "It's pants in the US and trousers in the UK. What would be a good universal "
    'term?',
    "What's your top tip for preventing headphone wires from getting in a knot?",
    'Have you ever had (or thought about having) anything printed on a T-shirt?',
    'What was it?',
    "What's the best tribute band name you've heard of?",
    'Were you ever given a gold star for your work in school? If not, did you '
    'want one?',
    "What food do you wish was poisonous so you wouldn't eat any more of it?",
    'If you could only have one color of T-shirt, what would it be, and why?',
    'What was the last thing you felt the need to have a five-minute rant about?',
    'Have you ever grown anything from a seed? What was it and did it survive?',
    'What\'s your best "found this in a blocked pipe” story?',
    'Do you know anyone who looks like their pet?',
    "What's the weirdest thing you've ever written an essay on?",
    'You need to remove one social media app from your phone; which one will it '
    'be?',
    "What's one ridiculous excuse you've given for not doing something you should "
    'have done?',
    'How much time do you spend on the internet on an average day?',
    'What popular trend do you find most annoying, and why?',
    "Everything in moderation is okay, but what shouldn't be done in moderation?",
    'Do you tend to Google your problems?',
    'Have you ever retold a fake news story that you thought was real? What was '
    'it?',
    'What do you often see in your home area that visitors will travel miles to '
    'see?',
    "Did you have acne as a teenager, and what's your best tip for dealing with "
    'it?',
    'Which color of jelly bean tastes best?',
    'If not cotton and linen paper, what would be a fun material to make dollar '
    'bills out of?',
    "Is there a TV cartoon that's been ruined by a remake since your childhood?",
    "What's the funniest rumor you've ever heard about yourself?",
    'You have a pet dragon. What have you named it?',
    'What do you need to change about yourself to become the person you want to '
    'be?',
    'How difficult would your life become if you tried to stop taking flights?',
    'What new hall of fame would you like to propose and who would be the first '
    'person in it?',
    "If not diamonds, what are a girl's best friend?",
    "What's the best put-down you've ever used or heard used?",
    "There's a Gum Wall in Seattle. What else could you stick on a wall to make "
    'it famous?',
    'What had you done (or not done) the last time someone got to say "| told you '
    'sol"?',
    "Who was the last person you thought about punching in the face (but didn't)?",
    'lf you had to wear a hat every day for the rest of your life, what sort of '
    'hat would you choose?',
    "What's the biggest thing you ever built with Lego bricks?",
    "You're writing a novel about insects taking over the world. What's its "
    'title?',
    'Which one of your friends or family has the funniest way of sneezing?',
    'How many bands can you think of that have a color in their name?',
    'What toy would you like to see added to the characters in Toy Story?',
    'lf you could change your accent, which one would you choose?',
    'What do you now accept that you always pushed back against in the past?',
    'Could you land a plane in an emergency if air traffic control talked you '
    'through it?',
    'Were you afraid to go back in the water after seeing Jaws?',
    "What's the best thing about being you?",
    'If you could only have a sixty-second shower once a week, which body parts '
    'would you target?',
    'Which one of your friends or family has the cheesiest feet?',
    'When you were little, did you have a funny word for something because you '
    "couldn't say the real word? What was it?",
    "What's the most despicable thing you've ever done?",
    'Do you agree that crime never pays? Why?',
    "What's the most amazing photo you've seen taken by a camera drone?",
    'Has anyone ever shown you a prized possession you found slightly creepy?',
    'What was it?',
    'What new color of toilet paper should be available?',
    'When was the last time you felt Lady Luck was smiling on you?',
    "What's the most amazing thing you've seen a balloon artist make?",
    'lf you had to wear clown shoes for a day, what would you find most '
    'difficult?',
    'What tool would be a great addition to a Swiss army knife?',
    'You need to prepare a meal with lentils as the main ingredient. What will '
    'you make?',
    'What\'s your best "knock, knock" joke?',
    'If you were holding a workplace (or school) Olympics, what events would you '
    'include?',
    "What's your favorite inspirational quote?",
    'Should organ donation should be mandatory?',
    "What's the furthest in advance you've bought tickets for something?",
    'Who in your family is the biggest tea connoisseur?',
    "What's the most unusual mode of transport you've used?",
    'If you were handed conscription papers in WWI, would you have been a '
    'conscientious objector?',
    "What's the most desperate thing you've seen new parents doing to try to get "
    'a baby to sleep?',
    'Have you ever given someone an unkind nickname? What was it?',
    "What's the softest thing you've ever touched?",
    'When was the last time someone asked you for help? What did they need help '
    'with?',
    'What food are you almost embarrassed to say you like?',
    'How much of a head start would you need on Usain Bolt to get from your '
    'kitchen to the bathroom first?',
    "What's the most uncomfortable item you've ever worn in the name of fashion?",
    'Which college degree is least helpful in terms of finding a job?',
    "What's the most ridiculous excuse you've heard for not showing up somewhere "
    'that turned out to be true?',
    'If not curved, what shape should bananas be?',
    'What time was bedtime when you were ten?',
    "It's Saturday night and the power will be out for at least two hours. What "
    'will you do?',
    'What hairstyle have you had that makes you cringe when you see old '
    'photographs?',
    'You need to remove a firmly fixed adhesive bandage from your leg. How do you '
    'do it?',
    'What was the last thing you dreaded doing that turned out to be not as bad '
    'as you imagined?',
    "What's the laziest yet incredibly ingenious thing you've seen someone do?",
    'If not cloud nine, what cloud number would you like to be on, and why?',
    'What alternative medals might be presented in the Olympics in a parallel '
    'universe?',
    'Who was the last person you visited in hospital?',
    "What's the most impressive natural sight you've seen?",
    "Is there a type of music that you just can't listen to? What is it?",
    "What's the single most important thing needed to make a relationship work?",
    'Which one of your friends is the moodiest, and what do you do to snap them '
    'out of a cranky mood?',
    "What's the solution to endangered animals eating endangered plants?",
    'You\'re writing a poem. What do you rhyme with “looking at the sun"?',
    'What\'s your best "neighbors-from-hell" story?',
    'If you could only buy one new item of clothing in a year, what would it be?',
    'What new flavor of potato chip would you like to create?',
    'How many bands can you think of with a number in their name?',
    "What's the weirdest thing you could bury today to confuse future "
    'archaeologists?',
    'Have you ever been to a drive-in movie theater?',
    'What has turned out to be much harder than you anticipated?',
    'How much money would you need to win on the lottery before you would give up '
    'your job?',
    'What poem or speech would you most like to be able to recite by heart?',
    'Where were you when you last saw a fireworks display?',
    "What's the best thing you've seen on TV that you happened upon by chance?",
    "What's the longest time you've been stuck in a traffic jam? Where were you "
    'going?',
    'If not a ponytail, what animal part would be a good way to describe your '
    'hair?',
    'What three words would you use to describe the feeling of being in love?',
    "Have you ever been the center of attention when you didn't want to be?",
    'When?',
    "What's the cutest thing you've ever seen?",
    'Is there a reason for everything?',
    'What additional rule would make marathon running a more interesting '
    'spectator sport?',
    "You are a notorious cat burglar. What's been your most daring theft?",
    "What was the last thing you did that you don't like when other people do it?",
    'How many times do you look at your phone on an average day?',
    'Which of your battery-operated gadgets needs the most batteries?',
    'What meal could you make using only the items in your fridge right now?',
    'Shorts combined with a skirt are skorts. What other clothing combo could you '
    'create and what would you call it?',
    "What makes you sure that you're not living in a computer simulation?",
    'Can thought influence reality? How?',
    "What's one thing you wouldn't do for health reasons?",
    'Have you ever had a gut feeling that something bad was going to happen and '
    'then it did?',
    "What do you find most distracting when you're trying to concentrate?",
    "Is there a place where you're no longer welcome? Where and why?",
    'What would you like to teach a parrot to say?',
    'Does every cloud have a silver lining?',
    'When was the last time you felt the wind in your hair?',
    "What's the most outrageous color of pants you've ever worn (not on a golf "
    'course!)?',
    'If you could make origami towels, what shape would you make?',
    "What's the most interesting thing you've learned through watching a "
    'documentary?',
    "When you're searching for ideas, where do you go to find them?",
    "What's the most romantic thing someone has ever done for you?",
    "You've been asked to create a themed room in a hotel. What theme would you "
    'choose?',
    'When something good happens to you, who is the first person you want to tell '
    'about it?',
    "What's the one thing you know you're really good at?",
    'Have you ever given anything a Zero rating in a feedback questionnaire? What '
    'was it?',
    'What pizza topping should never have been invented?',
    'Who was your least favorite teacher at school, and why?',
    "What's the riskiest thing you've ever done?",
    'How many times do you chew your food before swallowing?',
    "What's the most disgusting food combination your friends eat?",
    'As a child, what songs did you sing or games did you play in the car on long '
    'journeys?',
    'Have you ever had a great idea that turned out to be a bad idea?',
    'What do you find a breeze that many others find a challenge?',
    "What's your best bounce-house story?",
    'Do you believe in UFOs, and have you seen one?'
]
